@@ -19,7 +19,7 @@ CONTROL_DICT = {1: ("bionic",   "18.04", False,             False, 3),
                 2: ("focal",    "20.04", True,              True,  4),
                 3: ("jammy",    "20.04", True,              True,  4),
                 4: ("noble",    "24.04", True,              True,  4),
-                5: ("oracular", "24.04", True,              True,  4)}
+                5: ("plucky",   "25.04", True,              True,  4)}
 
 def f_changelog_setup_for(package_num):
     changelog_lines = []
@@ -58,8 +58,8 @@ def f_cmakelists_setup_for(package_num):
 
     for i in range(len(cmakelists_lines)):
         # pkg_check_modules(GTKSV gtksourceview-4 REQUIRED)
-        if cmakelists_lines[i].find("pkg_check_modules(GTKSV gtksourceview-") >= 0:
-            cmakelists_lines[i] = "pkg_check_modules(GTKSV gtksourceview-{} REQUIRED)\n".format("3.0" if 3 == CONTROL_DICT[package_num][4] else "4")
+        if cmakelists_lines[i].find("pkg_check_modules(GTKSV gtksourceview-") >= 0 and not "gtksourceview-5" in cmakelists_lines[i]:
+            cmakelists_lines[i] = "  pkg_check_modules(GTKSV gtksourceview-{} REQUIRED)\n".format("3.0" if 3 == CONTROL_DICT[package_num][4] else "4")
             break
     else:
         print("!! cmakelists 'pkg_check_modules(GTKSV gtksourceview-' not found")
