@@ -43,6 +43,7 @@ public:
      : _pCtMainWin{pCtMainWin}
      , _pCtConfig{pCtMainWin->get_ct_config()}
     {
+        _s_options.pMultipleWordsSearchType = &_pCtConfig->multipleWordsSearchType;
         _find_init();
         _validate_enable_spell_check();
     }
@@ -125,23 +126,23 @@ private:
                    const bool add_as_child,
                    const CtTreeIter* pCtTreeIterFrom = nullptr,
                    CtMainWin* pWinToCopyFrom = nullptr);
-    Gtk::TreeIter _node_add_with_data(Gtk::TreeIter curr_iter,
+    Gtk::TreeModel::iterator _node_add_with_data(Gtk::TreeModel::iterator curr_iter,
                                       CtNodeData& nodeData,
                                       const bool add_as_child,
                                       std::shared_ptr<CtNodeState> node_state);
 
 public:
-    Gtk::TreeIter node_child_exist_or_create(Gtk::TreeIter parentIter,
+    Gtk::TreeModel::iterator node_child_exist_or_create(Gtk::TreeModel::iterator parentIter,
                                              const std::string& nodeName,
                                              const bool focusIfExisting = true);
-    void node_move_after(Gtk::TreeIter iter_to_move,
-                         Gtk::TreeIter father_iter,
-                         Gtk::TreeIter brother_iter = Gtk::TreeIter{},
+    void node_move_after(Gtk::TreeModel::iterator iter_to_move,
+                         Gtk::TreeModel::iterator father_iter,
+                         Gtk::TreeModel::iterator brother_iter = Gtk::TreeModel::iterator{},
                          bool set_first = false);
 
 private:
-    bool _need_node_swap(Gtk::TreeIter& leftIter,
-                         Gtk::TreeIter& rightIter,
+    bool _need_node_swap(Gtk::TreeModel::iterator& leftIter,
+                         Gtk::TreeModel::iterator& rightIter,
                          bool ascendings);
     bool _tree_sort_level_and_sublevels(const Gtk::TreeNodeChildren& children,
                                         bool ascending);
@@ -245,6 +246,7 @@ public:
     void find_matches_store_reset();
     static void find_match_in_obj_focus(const int obj_offset,
                                         Glib::RefPtr<Gtk::TextBuffer> pTextBuffer,
+                                        CtMainWin* pCtMainWin,
                                         const CtTreeIter& tree_iter,
                                         const CtAnchWidgType anch_type,
                                         const size_t anch_cell_idx,
@@ -292,6 +294,8 @@ public:
     void nodes_collapse_all();
     void toolbar_icons_size_increase();
     void toolbar_icons_size_decrease();
+    void more_nodes_on_node_name_header();
+    void less_nodes_on_node_name_header();
     void toggle_fullscreen();
     void toggle_always_on_top();
     void disable_menubar_in_titlebar() { _menubar_in_titlebar_set(false); }
@@ -315,12 +319,10 @@ private:
     text_view_n_buffer_codebox_proof _get_text_view_n_buffer_codebox_proof();
     CtCodebox* _codebox_in_use();
     CtTableCommon* _table_in_use();
-    void _save_tags_at_cursor_as_latest(Glib::RefPtr<Gtk::TextBuffer> rTextBuffer,
+    void _save_tags_at_cursor_as_latest(Glib::RefPtr<Gtk::TextBuffer> pTextBuffer,
                                         int cursorOffset);
     bool _links_entries_pre_dialog(const Glib::ustring& curr_link,
                                    CtLinkEntry& link_entry);
-    Glib::ustring _links_entries_post_dialog(CtLinkEntry& link_entry);
-    Glib::ustring _link_check_around_cursor();
 
 public:
     // format actions
