@@ -189,6 +189,7 @@ void CtActions::preferences_import()
     _pCtConfig->nodesOnNodeNameHeader = ctConfigImported.nodesOnNodeNameHeader;
     _pCtConfig->maxMatchesInPage = ctConfigImported.maxMatchesInPage;
     _pCtConfig->toolbarIconSize = ctConfigImported.toolbarIconSize;
+    _pCtConfig->multipleWordsSearchType = ctConfigImported.multipleWordsSearchType;
     _pCtConfig->currColour_fg = ctConfigImported.currColour_fg;
     _pCtConfig->currColour_bg = ctConfigImported.currColour_bg;
     _pCtConfig->currColour_nn = ctConfigImported.currColour_nn;
@@ -235,6 +236,7 @@ void CtActions::preferences_import()
     _pCtConfig->urlAutoLink = ctConfigImported.urlAutoLink;
     _pCtConfig->camelCaseAutoLink = ctConfigImported.camelCaseAutoLink;
     _pCtConfig->tripleClickParagraph = ctConfigImported.tripleClickParagraph;
+    _pCtConfig->doubleClickLink = ctConfigImported.doubleClickLink;
     _pCtConfig->enableSymbolAutoreplace = ctConfigImported.enableSymbolAutoreplace;
     _pCtConfig->wrappingIndent = ctConfigImported.wrappingIndent;
     _pCtConfig->autoIndent = ctConfigImported.autoIndent;
