@@ -1,7 +1,7 @@
 /*
  * ct_actions_find.cc
  *
- * Copyright 2009-2024
+ * Copyright 2009-2025
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -23,7 +23,6 @@
 
 #include "ct_actions.h"
 #include <gtkmm/dialog.h>
-#include <gtkmm/stock.h>
 #include <glibmm/regex.h>
 #include <regex>
 #include "ct_image.h"
@@ -176,7 +175,7 @@ void CtActions::find_in_multiple_nodes_ok_clicked()
     CtStatusBar& ctStatusBar = _pCtMainWin->get_status_bar();
     CtTreeStore& ctTreeStore = _pCtMainWin->get_tree_store();
 
-    Gtk::TreeIter node_iter;
+    Gtk::TreeModel::iterator node_iter;
     bool forward = _s_options.direction_fw;
     if (_s_state.from_find_back) {
         forward = not forward;
@@ -216,8 +215,8 @@ void CtActions::find_in_multiple_nodes_ok_clicked()
         _s_state.all_matches_first_in_node = true;
         CtTreeIter ct_node_iter = ctTreeStore.to_ct_tree_iter(node_iter);
         if (_s_options.node_content) {
-            Glib::RefPtr<Gtk::TextBuffer> rTextBuffer = ct_node_iter.get_node_text_buffer();
-            if (not rTextBuffer) {
+            Glib::RefPtr<Gtk::TextBuffer> pTextBuffer = ct_node_iter.get_node_text_buffer();
+            if (not pTextBuffer) {
                 CtDialogs::error_dialog(str::format(_("Failed to retrieve the content of the node '%s'"), ct_node_iter.get_node_name().raw()), *_pCtMainWin);
                 break;
             }
@@ -234,7 +233,7 @@ void CtActions::find_in_multiple_nodes_ok_clicked()
         ++_s_state.processed_nodes;
         if (_s_state.matches_num > 0 and not all_matches) break;
         if (_s_options.only_sel_n_subnodes and not _s_state.from_find_iterated) break;
-        Gtk::TreeIter last_top_node_iter = node_iter; // we need this if we start from a node that is not in top level
+        Gtk::TreeModel::iterator last_top_node_iter = node_iter; // we need this if we start from a node that is not in top level
         if (forward) { ++node_iter; }
         else         { --node_iter; }
         if (not node_iter and _s_options.only_sel_n_subnodes) break;
@@ -433,13 +432,13 @@ CtMatchType CtActions::_parse_given_node_content(CtTreeIter node_iter,
     if (not node_iter.get_node_children_are_excluded_from_search() or _s_options.override_exclusions) {
         // check for children
         if (not node_iter->children().empty()) {
-            Gtk::TreeIter child_iter = forward ? node_iter->children().begin() : --node_iter->children().end();
+            Gtk::TreeModel::iterator child_iter = forward ? node_iter->children().begin() : --node_iter->children().end();
             while (child_iter and not _pCtMainWin->get_status_bar().is_progress_stop()) {
                 _s_state.all_matches_first_in_node = true;
                 CtTreeIter ct_node_iter = ctTreeStore.to_ct_tree_iter(child_iter);
                 if (_s_options.node_content) {
-                    Glib::RefPtr<Gtk::TextBuffer> rTextBuffer = ct_node_iter.get_node_text_buffer();
-                    if (not rTextBuffer) {
+                    Glib::RefPtr<Gtk::TextBuffer> pTextBuffer = ct_node_iter.get_node_text_buffer();
+                    if (not pTextBuffer) {
                         CtDialogs::error_dialog(str::format(_("Failed to retrieve the content of the node '%s'"), ct_node_iter.get_node_name().raw()), *_pCtMainWin);
                         break;
                     }
@@ -492,7 +491,7 @@ bool CtActions::_parse_node_name_n_tags_iter(CtTreeIter& node_iter,
         if (all_matches) {
             gint64 node_id = node_iter.get_node_id();
             Glib::ustring node_hier_name = CtMiscUtil::get_node_hierarchical_name(node_iter, "  /  ", false/*for_filename*/, true/*root_to_leaf*/);
-            Glib::ustring line_content = CtTextIterUtil::get_first_line_content(node_iter.get_node_text_buffer());
+            const Glib::ustring line_content = CtTextIterUtil::get_first_line_content(node_iter.get_node_text_buffer());
             const Glib::ustring text_tags = node_iter.get_node_tags();
             _s_state.match_store->add_row(node_id,
                                           text_tags.empty() ? node_name : node_name + "\n [" +  _("Tags") + _(": ") + text_tags + "]",
@@ -533,6 +532,7 @@ bool CtActions::_parse_node_content_iter(const CtTreeIter& tree_iter,
     }
     else {
         start_iter = forward ? text_buffer->begin() : text_buffer->end();
+        //spdlog::debug("fw={} nosel m={} M={} -> s={}", forward, text_buffer->begin().get_offset(), text_buffer->end().get_offset(), start_iter.get_offset());
         if (all_matches) _s_state.all_matches_first_in_node = false;
     }
     //spdlog::debug("parsing {} content from {} ffs={} 1st={}", tree_iter.get_node_id(), start_iter.get_offset(), first_fromsel, first_node);
@@ -597,7 +597,34 @@ Glib::RefPtr<Glib::Regex> CtActions::_create_re_pattern(Glib::ustring pattern)
     if (_s_options.accent_insensitive) {
         pattern = str::diacritical_to_ascii(pattern);
     }
-    if (not _s_options.reg_exp) { // NOT REGULAR EXPRESSION
+    bool temp_reg_exp{false};
+    if (not _s_options.reg_exp and 0 != *_s_options.pMultipleWordsSearchType) {
+        const std::vector<Glib::ustring> splitted = str::split(pattern, " ", true/*compress*/);
+        if (splitted.size() > 1u) {
+            temp_reg_exp = true;
+            pattern.clear();
+            if (1 == *_s_options.pMultipleWordsSearchType) {
+                // 1 = disregard order = AND -> (?=.*Word1)(?=.*Word2).*
+                for (const Glib::ustring& element : splitted) {
+                    pattern += "(?=.*" + Glib::Regex::escape_string(element) + ")";
+                }
+                pattern += ".*";
+            }
+            else {
+                // 2 = match any = OR -> .*(Word1|Word2).*
+                pattern += ".*(";
+                bool first_loop{true};
+                for (const Glib::ustring& element : splitted) {
+                    if (first_loop) { first_loop = false; }
+                    else { pattern += "|"; }
+                    pattern += Glib::Regex::escape_string(element);
+                }
+                pattern += ").*";
+            }
+            spdlog::debug("auto reg_exp {}", pattern.c_str());
+        }
+    }
+    if (not _s_options.reg_exp and not temp_reg_exp) { // NOT REGULAR EXPRESSION
         pattern = Glib::Regex::escape_string(pattern);     // backslashes all non alphanum chars => to not spoil re
         if (_s_options.whole_word)      // WHOLE WORD
             pattern = "\\b" + pattern + "\\b";
@@ -647,9 +674,10 @@ bool CtActions::_find_pattern(CtTreeIter tree_iter,
                 match_offsets = curr_pair;
                 _s_state.latest_node_offset_match_start = match_offsets.first;
                 _s_state.latest_node_offset_match_end = match_offsets.second;
-                //spdlog::debug("{}->{}", curr_pair.first, curr_pair.second);
+                //spdlog::debug("OK {}->{}", curr_pair.first, curr_pair.second);
                 break;
             }
+            //spdlog::debug("NOK {}->{}", curr_pair.first, curr_pair.second);
             match_info.next();
         }
     }
@@ -686,7 +714,8 @@ bool CtActions::_find_pattern(CtTreeIter tree_iter,
     if (not forward) {
         std::swap(obj_search_start_offs, obj_search_end_offs);
     }
-    if (_check_pattern_in_object_between(tree_iter,
+    if (tree_iter.get_node_is_rich_text() and
+        _check_pattern_in_object_between(tree_iter,
                                          re_pattern,
                                          obj_search_start_offs,
                                          obj_search_end_offs,
@@ -733,8 +762,8 @@ bool CtActions::_find_pattern(CtTreeIter tree_iter,
     if (match_offsets.first == -1) return false;
 
     // match found!
+    const int num_objs = _get_num_objs_before_offset(text_buffer, match_offsets.first);
     if (0u == anchMatchList.size()) {
-        const int num_objs = _get_num_objs_before_offset(text_buffer, match_offsets.first);
         _s_state.latest_match_offsets.first = match_offsets.first + num_objs;
         _s_state.latest_match_offsets.second = match_offsets.second + num_objs;
     }
@@ -742,7 +771,71 @@ bool CtActions::_find_pattern(CtTreeIter tree_iter,
         // the match offset comes from the anchored widget
         _s_state.latest_match_offsets.first = match_offsets.first;
         _s_state.latest_match_offsets.second = match_offsets.second;
+        _s_state.latest_node_offset_match_start = match_offsets.first - num_objs;
+        _s_state.latest_node_offset_match_end = match_offsets.second - num_objs;
     }
+    auto f_match_replace_link = [this, &tree_iter, &re_pattern](Glib::RefPtr<Gtk::TextBuffer> pTextBuffer,
+                                                                const int textIterOffset,
+                                                                const int startOffset,
+                                                                int& endOffset)->bool{
+        if (tree_iter.get_node_read_only()) return false;
+        Gtk::TextIter textIter = pTextBuffer->get_iter_at_offset(textIterOffset);
+        if (not textIter) {
+            spdlog::warn("!! f_match_replace_link unexp no TextIter offset {}", textIterOffset);
+            return false;
+        }
+        Glib::ustring tag_property = CtMiscUtil::link_check_around_cursor(pTextBuffer, textIter);
+        if (tag_property.empty()) {
+            spdlog::warn("!! f_match_replace_link unexp no link_check_around_cursor offset {}", textIterOffset);
+            return false;
+        }
+        CtLinkEntry link_entry = CtMiscUtil::get_link_entry_from_property(tag_property);
+        if (CtLinkType::None == link_entry.type) {
+            spdlog::warn("!! f_match_replace_link unexp CtLinkType::None tag_property '{}'", tag_property.c_str());
+            return false;
+        }
+        Glib::ustring text_searchable = link_entry.get_target_searchable();
+        const Glib::ustring pre_text = text_searchable.substr(0, startOffset);
+        const Glib::ustring origin_text = text_searchable.substr(startOffset, endOffset - startOffset);
+        const Glib::ustring post_text = text_searchable.substr(endOffset);
+        Glib::ustring replacer_text = _s_options.str_replace; /* use Glib::ustring to count symbols */
+        // use re_pattern->replace for the cases with \n, maybe it even helps with groups
+        if (_s_options.reg_exp) {
+            replacer_text = re_pattern->replace(origin_text, 0, replacer_text, static_cast<Glib::RegexMatchFlags>(0));
+        }
+        const Glib::ustring out_text_searchable = pre_text + replacer_text + post_text;
+        link_entry.set_target_searchable(out_text_searchable);
+        const Glib::ustring property_value = CtMiscUtil::get_link_property_from_entry(link_entry);
+        _pCtMainWin->get_ct_actions()->apply_tag(CtConst::TAG_LINK, property_value);
+        endOffset = startOffset + replacer_text.size();
+        _s_state.replace_subsequent = true;
+        _pCtMainWin->get_state_machine().update_state(tree_iter);
+        tree_iter.pending_edit_db_node_buff();
+        return true;
+    };
+    auto f_match_replace_image_png = [this, &tree_iter, &re_pattern](CtImagePng* pImagePng,
+                                                                     const int startOffset,
+                                                                     int& endOffset)->bool{
+        if (tree_iter.get_node_read_only()) return false;
+        CtLinkEntry link_entry = CtMiscUtil::get_link_entry_from_property(pImagePng->get_link());
+        Glib::ustring text_searchable = link_entry.get_target_searchable();
+        const Glib::ustring pre_text = text_searchable.substr(0, startOffset);
+        const Glib::ustring origin_text = text_searchable.substr(startOffset, endOffset - startOffset);
+        const Glib::ustring post_text = text_searchable.substr(endOffset);
+        Glib::ustring replacer_text = _s_options.str_replace; /* use Glib::ustring to count symbols */
+        // use re_pattern->replace for the cases with \n, maybe it even helps with groups
+        if (_s_options.reg_exp) {
+            replacer_text = re_pattern->replace(origin_text, 0, replacer_text, static_cast<Glib::RegexMatchFlags>(0));
+        }
+        const Glib::ustring out_text_searchable = pre_text + replacer_text + post_text;
+        link_entry.set_target_searchable(out_text_searchable);
+        pImagePng->set_link(CtMiscUtil::get_link_property_from_entry(link_entry));
+        endOffset = startOffset + replacer_text.size();
+        _s_state.replace_subsequent = true;
+        _pCtMainWin->get_state_machine().update_state(tree_iter);
+        tree_iter.pending_edit_db_node_buff();
+        return true;
+    };
     auto f_match_replace_light_table = [this, &tree_iter, &re_pattern](CtTableLight* pTableLight,
                                                                        const int cellIdx,
                                                                        const int startOffset,
@@ -824,7 +917,9 @@ bool CtActions::_find_pattern(CtTreeIter tree_iter,
                 if ( _s_state.replace_active and
                      ( CtAnchWidgType::CodeBox == pAnchMatch->anch_type or
                        CtAnchWidgType::TableHeavy == pAnchMatch->anch_type or
-                       CtAnchWidgType::TableLight == pAnchMatch->anch_type ) )
+                       CtAnchWidgType::TableLight == pAnchMatch->anch_type or
+                       CtAnchWidgType::ImagePng == pAnchMatch->anch_type or
+                       CtAnchWidgType::Link == pAnchMatch->anch_type ) )
                 {
                     if ( last_obj_offs == pAnchMatch->start_offset and
                          last_cell_idx == pAnchMatch->anch_cell_idx )
@@ -839,7 +934,7 @@ bool CtActions::_find_pattern(CtTreeIter tree_iter,
                         accumulated_delta_offs = 0;
                     }
                     if (CtAnchWidgType::CodeBox == pAnchMatch->anch_type) {
-                        if (CtCodebox* pCodebox = dynamic_cast<CtCodebox*>(pAnchMatch->pAnchWidg)) {
+                        if (auto pCodebox = dynamic_cast<CtCodebox*>(pAnchMatch->pAnchWidg)) {
                             const int prev_anch_offs_end = pAnchMatch->anch_offs_end;
                             if (not f_match_replace_text_buffer(pCodebox->get_text_view().get_buffer(),
                                                                 pAnchMatch->anch_offs_start,
@@ -885,14 +980,43 @@ bool CtActions::_find_pattern(CtTreeIter tree_iter,
                             spdlog::warn("!! {} unexp no CtTableLight", __FUNCTION__);
                         }
                     }
+                    else if (CtAnchWidgType::ImagePng == pAnchMatch->anch_type) {
+                        if (auto pImagePng = dynamic_cast<CtImagePng*>(pAnchMatch->pAnchWidg)) {
+                            const int prev_anch_offs_end = pAnchMatch->anch_offs_end;
+                            if (not f_match_replace_image_png(pImagePng,
+                                                              pAnchMatch->anch_offs_start,
+                                                              pAnchMatch->anch_offs_end))
+                            {
+                                return false;
+                            }
+                            accumulated_delta_offs += (pAnchMatch->anch_offs_end - prev_anch_offs_end);
+                        }
+                        else {
+                            spdlog::warn("!! {} unexp no CtImagePng", __FUNCTION__);
+                        }
+                    }
+                    else if (CtAnchWidgType::Link == pAnchMatch->anch_type) {
+                        // we cannot rely on pAnchMatch->pAnchWidg as that is immediately freed
+                        const int prev_anch_offs_end = pAnchMatch->anch_offs_end;
+                        if (not f_match_replace_link(text_buffer,
+                                                     pAnchMatch->start_offset,
+                                                     pAnchMatch->anch_offs_start,
+                                                     pAnchMatch->anch_offs_end))
+                        {
+                            return false;
+                        }
+                        accumulated_delta_offs += (pAnchMatch->anch_offs_end - prev_anch_offs_end);
+                    }
                 }
+                const Glib::ustring line_content = pAnchMatch->line_content.size() <= CtTextIterUtil::LINE_CONTENT_LIMIT ?
+                    pAnchMatch->line_content : pAnchMatch->line_content.substr(0u, CtTextIterUtil::LINE_CONTENT_LIMIT) + "...";
                 (void)_s_state.match_store->add_row(node_id,
                                                     node_name_w_tags,
                                                     esc_node_hier_name,
                                                     _s_state.latest_match_offsets.first,
                                                     _s_state.latest_match_offsets.second,
                                                     line_num,
-                                                    pAnchMatch->line_content,
+                                                    line_content,
                                                     pAnchMatch->anch_type,
                                                     pAnchMatch->anch_cell_idx,
                                                     pAnchMatch->anch_offs_start,
@@ -952,9 +1076,33 @@ bool CtActions::_find_pattern(CtTreeIter tree_iter,
                         spdlog::warn("!! {} unexp no CtTableLight", __FUNCTION__);
                     }
                 }
+                else if (CtAnchWidgType::ImagePng == pAnchMatch->anch_type) {
+                    if (auto pImagePng = dynamic_cast<CtImagePng*>(pAnchMatch->pAnchWidg)) {
+                        if (not f_match_replace_image_png(pImagePng,
+                                                          pAnchMatch->anch_offs_start,
+                                                          pAnchMatch->anch_offs_end))
+                        {
+                            return false;
+                        }
+                    }
+                    else {
+                        spdlog::warn("!! {} unexp no CtImagePng", __FUNCTION__);
+                    }
+                }
+                else if (CtAnchWidgType::Link == pAnchMatch->anch_type) {
+                    // we cannot rely on pAnchMatch->pAnchWidg as that is immediately freed
+                    if (not f_match_replace_link(text_buffer,
+                                                 pAnchMatch->start_offset,
+                                                 pAnchMatch->anch_offs_start,
+                                                 pAnchMatch->anch_offs_end))
+                    {
+                        return false;
+                    }
+                }
             }
             CtActions::find_match_in_obj_focus(_s_state.latest_match_offsets.first,
                                                text_buffer,
+                                               _pCtMainWin,
                                                tree_iter,
                                                pAnchMatch->anch_type,
                                                pAnchMatch->anch_cell_idx,
@@ -968,7 +1116,7 @@ bool CtActions::_find_pattern(CtTreeIter tree_iter,
             {
                 return false;
             }
-            _pCtMainWin->get_text_view().set_selection_at_offset_n_delta(_s_state.latest_match_offsets.first,
+            ct_text_view.set_selection_at_offset_n_delta(_s_state.latest_match_offsets.first,
                 _s_state.latest_match_offsets.second - _s_state.latest_match_offsets.first);
         }
     }
@@ -977,6 +1125,7 @@ bool CtActions::_find_pattern(CtTreeIter tree_iter,
 
 /*static*/void CtActions::find_match_in_obj_focus(const int obj_offset,
                                                   Glib::RefPtr<Gtk::TextBuffer> pTextBuffer,
+                                                  CtMainWin* pCtMainWin,
                                                   const CtTreeIter& tree_iter,
                                                   const CtAnchWidgType anch_type,
                                                   const size_t anch_cell_idx,
@@ -985,9 +1134,26 @@ bool CtActions::_find_pattern(CtTreeIter tree_iter,
 {
     //spdlog::debug("{} obj={} cell={} {}->{}", __FUNCTION__, obj_offset, anch_cell_idx, anch_offs_start, anch_offs_end);
     Gtk::TextIter anchor_iter = pTextBuffer->get_iter_at_offset(obj_offset);
-    Glib::RefPtr<Gtk::TextChildAnchor> rChildAnchor = anchor_iter.get_child_anchor();
-    if (rChildAnchor) {
-        CtAnchoredWidget* pCtAnchoredWidget = tree_iter.get_anchored_widget(rChildAnchor);
+    if (CtAnchWidgType::Link == anch_type) {
+        std::optional<Glib::ustring> tag_name = CtTextIterUtil::iter_get_tag_startingwith(anchor_iter, CtConst::TAG_LINK_PREFIX);
+        if (tag_name.has_value()) {
+            Glib::RefPtr<Gtk::TextTag> pTextTag = pCtMainWin->get_text_tag_table()->lookup(tag_name.value());
+            Gtk::TextIter textIterEndTmp{anchor_iter};
+            (void)textIterEndTmp.forward_to_tag_toggle(pTextTag);
+            Gtk::TextIter textIterStartTmp{anchor_iter};
+            (void)textIterStartTmp.backward_to_tag_toggle(pTextTag);
+            const int start_offset = textIterStartTmp.get_offset();
+            const int end_offset = textIterEndTmp.get_offset();
+            pCtMainWin->get_text_view().set_selection_at_offset_n_delta(start_offset, end_offset - start_offset, pTextBuffer);
+        }
+        else {
+            spdlog::debug("? {} !tag_name", __FUNCTION__);
+        }
+        return;
+    }
+    Glib::RefPtr<Gtk::TextChildAnchor> pChildAnchor = anchor_iter.get_child_anchor();
+    if (pChildAnchor) {
+        CtAnchoredWidget* pCtAnchoredWidget = tree_iter.get_anchored_widget(pChildAnchor);
         if (pCtAnchoredWidget) {
             switch (anch_type) {
                 case CtAnchWidgType::CodeBox: {
@@ -1022,7 +1188,7 @@ bool CtActions::_find_pattern(CtTreeIter tree_iter,
         }
     }
     else {
-        spdlog::debug("? {} !rChildAnchor", __FUNCTION__);
+        spdlog::debug("? {} !pChildAnchor", __FUNCTION__);
     }
 }
 
@@ -1073,6 +1239,77 @@ bool CtActions::_check_pattern_in_object(Glib::RefPtr<Glib::Regex> re_pattern,
                 spdlog::warn("!! unexp no CtImageAnchor");
             }
         } break;
+        case CtAnchWidgType::ImagePng: {
+            if (CtImagePng* pCtImagePng = dynamic_cast<CtImagePng*>(pAnchWidg)) {
+                CtLinkEntry link_entry = CtMiscUtil::get_link_entry_from_property(pCtImagePng->get_link());
+                if (CtLinkType::None != link_entry.type) {
+                    Glib::ustring text = link_entry.get_target_searchable();
+                    if (_s_options.accent_insensitive) {
+                        text = str::diacritical_to_ascii(text);
+                    }
+                    Glib::MatchInfo match_info;
+                    if (re_pattern->match(text, match_info)) {
+                        CtAnchMatchList localAnchMatchList;
+                        while (match_info.matches()) {
+                            int match_start_offset, match_end_offset;
+                            match_info.fetch_pos(0, match_start_offset, match_end_offset);
+                            match_start_offset = str::byte_pos_to_symb_pos(text, match_start_offset);
+                            match_end_offset = str::byte_pos_to_symb_pos(text, match_end_offset);
+                            auto pAnchMatch = std::make_shared<CtAnchMatch>();
+                            pAnchMatch->start_offset = pAnchWidg->getOffset();
+                            pAnchMatch->line_content = text;
+                            pAnchMatch->anch_type = anchWidgType;
+                            pAnchMatch->anch_offs_start = match_start_offset;
+                            pAnchMatch->anch_offs_end = match_end_offset;
+                            pAnchMatch->pAnchWidg = pAnchWidg;
+                            localAnchMatchList.push_back(pAnchMatch);
+                            match_info.next();
+                        }
+                        for (auto& pAnchMatch : localAnchMatchList) {
+                            anchMatchList.push_back(pAnchMatch);
+                        }
+                        retVal = true;
+                    }
+                }
+            }
+            else {
+                spdlog::warn("!! unexp no CtImagePng");
+            }
+        } break;
+        case CtAnchWidgType::Link: {
+            if (CtAnchWidgLink* pAnchWidgLink = dynamic_cast<CtAnchWidgLink*>(pAnchWidg)) {
+                Glib::ustring text = pAnchWidgLink->get_target_searchable();
+                if (_s_options.accent_insensitive) {
+                    text = str::diacritical_to_ascii(text);
+                }
+                Glib::MatchInfo match_info;
+                if (re_pattern->match(text, match_info)) {
+                    CtAnchMatchList localAnchMatchList;
+                    while (match_info.matches()) {
+                        int match_start_offset, match_end_offset;
+                        match_info.fetch_pos(0, match_start_offset, match_end_offset);
+                        match_start_offset = str::byte_pos_to_symb_pos(text, match_start_offset);
+                        match_end_offset = str::byte_pos_to_symb_pos(text, match_end_offset);
+                        auto pAnchMatch = std::make_shared<CtAnchMatch>();
+                        pAnchMatch->start_offset = pAnchWidg->getOffset();
+                        pAnchMatch->line_content = text;
+                        pAnchMatch->anch_type = anchWidgType;
+                        pAnchMatch->anch_offs_start = match_start_offset;
+                        pAnchMatch->anch_offs_end = match_end_offset;
+                        //pAnchMatch->pAnchWidg = pAnchWidg; THIS TEMPORARY ANCHOR-LIKE WIDGET WILL BE FREED IMMEDIATELY!
+                        localAnchMatchList.push_back(pAnchMatch);
+                        match_info.next();
+                    }
+                    for (auto& pAnchMatch : localAnchMatchList) {
+                        anchMatchList.push_back(pAnchMatch);
+                    }
+                    retVal = true;
+                }
+            }
+            else {
+                spdlog::warn("!! unexp no CtAnchWidgLink");
+            }
+        } break;
         case CtAnchWidgType::CodeBox: {
             if (CtCodebox* pCodebox = dynamic_cast<CtCodebox*>(pAnchWidg)) {
                 Glib::ustring text = pCodebox->get_text_content();
@@ -1168,7 +1405,7 @@ bool CtActions::_check_pattern_in_object_between(CtTreeIter tree_iter,
                                                  CtAnchMatchList& anchMatchList)
 {
     bool retVal{false};
-    std::list<CtAnchoredWidget*> obj_vec = tree_iter.get_anchored_widgets(start_offset, end_offset);
+    std::list<CtAnchoredWidget*> obj_vec = tree_iter.get_anchored_widgets(start_offset, end_offset, true/*also_links*/);
     if (not forward) {
         std::reverse(obj_vec.begin(), obj_vec.end());
     }
@@ -1182,6 +1419,12 @@ bool CtActions::_check_pattern_in_object_between(CtTreeIter tree_iter,
             }
         }
     }
+    // cleanup for get_anchored_widgets with also_links!
+    for (CtAnchoredWidget* pAnchWidg : obj_vec) {
+        if (CtAnchWidgType::Link == pAnchWidg->get_type()) {
+            delete pAnchWidg;
+        }
+    }
     return retVal;
 }
 
