@@ -27,7 +27,6 @@
 #include "ct_clipboard.h"
 #include "ct_storage_control.h"
 #include <gtkmm/dialog.h>
-#include <gtkmm/stock.h>
 #include <cstdlib>
 #include "ct_logging.h"
 #include "ct_list.h"
@@ -50,7 +49,7 @@ void CtActions::link_cut()
 {
     if (not _is_curr_node_not_read_only_or_error()) return;
     _link_right_click_pre_action();
-    if (not _link_check_around_cursor().empty()) {
+    if (not CtMiscUtil::link_check_around_cursor(_curr_buffer()).empty()) {
         g_signal_emit_by_name(G_OBJECT(_pCtMainWin->get_text_view().gobj()), "cut-clipboard");
     }
 }
@@ -58,7 +57,7 @@ void CtActions::link_cut()
 void CtActions::link_copy()
 {
     _link_right_click_pre_action();
-    if (not _link_check_around_cursor().empty()) {
+    if (not CtMiscUtil::link_check_around_cursor(_curr_buffer()).empty()) {
         g_signal_emit_by_name(G_OBJECT(_pCtMainWin->get_text_view().gobj()), "copy-clipboard");
     }
 }
@@ -67,7 +66,7 @@ void CtActions::link_dismiss()
 {
     if (not _is_curr_node_not_read_only_or_error()) return;
     _link_right_click_pre_action();
-    if (not _link_check_around_cursor().empty()) {
+    if (not CtMiscUtil::link_check_around_cursor(_curr_buffer()).empty()) {
         _remove_text_formatting(true/*dismiss_link*/);
     }
 }
@@ -76,7 +75,7 @@ void CtActions::link_delete()
 {
     if (not _is_curr_node_not_read_only_or_error()) return;
     _link_right_click_pre_action();
-    if (not _link_check_around_cursor().empty()) {
+    if (not CtMiscUtil::link_check_around_cursor(_curr_buffer()).empty()) {
         _curr_buffer()->erase_selection(true, _pCtMainWin->get_text_view().mm().get_editable());
         _pCtMainWin->get_text_view().mm().grab_focus();
     }
@@ -313,7 +312,7 @@ void CtActions::image_link_edit()
     if (not _is_curr_node_not_read_only_or_error()) return;
     _link_entry = CtLinkEntry();
     if (curr_image_anchor->get_link().empty()) {
-        _link_entry.type = CtConst::LINK_TYPE_WEBS; // default value
+        _link_entry.type = CtLinkType::Webs; // default value
     }
     else if (not _links_entries_pre_dialog(curr_image_anchor->get_link(), _link_entry)) {
         return;
@@ -322,7 +321,7 @@ void CtActions::image_link_edit()
     if (not CtDialogs::link_handle_dialog(*_pCtMainWin, _("Insert/Edit Link"), sel_tree_iter, _link_entry)) {
         return;
     }
-    Glib::ustring property_value = _links_entries_post_dialog(_link_entry);
+    Glib::ustring property_value = CtMiscUtil::get_link_property_from_entry(_link_entry);
     if (not property_value.empty()) {
         curr_image_anchor->set_link(property_value);
         curr_image_anchor->update_label_widget();
@@ -345,8 +344,8 @@ void CtActions::toggle_show_hide_main_window()
 
 void CtActions::link_clicked(const Glib::ustring& tag_property_value, bool from_wheel)
 {
-    CtLinkEntry link_entry = CtMiscUtil::get_link_entry(tag_property_value);
-    if (link_entry.type == CtConst::LINK_TYPE_WEBS) { // link to webpage
+    CtLinkEntry link_entry = CtMiscUtil::get_link_entry_from_property(tag_property_value);
+    if (CtLinkType::Webs == link_entry.type) { // link to webpage
         Glib::ustring clean_weblink = str::replace(link_entry.webs, "amp;", "");
         if (_pCtConfig->weblinkCustomOn) {
             std::string cmd = fmt::sprintf(_pCtConfig->weblinkCustomAct, clean_weblink.raw());
@@ -361,7 +360,7 @@ void CtActions::link_clicked(const Glib::ustring& tag_property_value, bool from_
             fs::open_weblink(clean_weblink);
         }
     }
-    else if (link_entry.type == CtConst::LINK_TYPE_FILE) { // link to file
+    else if (CtLinkType::File == link_entry.type) { // link to file
         fs::path filepath = fs::path{link_entry.file}.string_native();
         if (filepath.is_relative()) filepath = fs::canonical(filepath, _pCtMainWin->get_ct_storage()->get_file_path().parent_path());
         if (from_wheel) {
@@ -380,7 +379,7 @@ void CtActions::link_clicked(const Glib::ustring& tag_property_value, bool from_
             fs::open_filepath(filepath, true, _pCtConfig);
         }
     }
-    else if (link_entry.type == CtConst::LINK_TYPE_FOLD) { // link to folder
+    else if (CtLinkType::Fold == link_entry.type) { // link to folder
         fs::path folderpath = fs::path{link_entry.fold}.string_native();
         if (folderpath.is_relative()) folderpath = fs::canonical(folderpath, _pCtMainWin->get_ct_storage()->get_file_path().parent_path());
         if (from_wheel) {
@@ -392,7 +391,7 @@ void CtActions::link_clicked(const Glib::ustring& tag_property_value, bool from_
         }
         fs::open_folderpath(folderpath, _pCtConfig);
     }
-    else if (link_entry.type == CtConst::LINK_TYPE_NODE) { // link to a tree node
+    else if (CtLinkType::Node == link_entry.type) { // link to a tree node
         CtTreeIter tree_iter = _pCtMainWin->get_tree_store().get_node_from_node_id(link_entry.node_id);
         if (not tree_iter) {
             CtDialogs::error_dialog(str::format(_("The Link Refers to a Node that Does Not Exist Anymore (Id = %s)"), std::to_string(link_entry.node_id)), *_pCtMainWin);
@@ -432,8 +431,7 @@ void CtActions::current_node_scroll_to_anchor(Glib::ustring anchor_name)
     }
     else {
         Gtk::TextIter iter_anchor = _curr_buffer()->get_iter_at_child_anchor(imageAnchor->getTextChildAnchor());
-        _curr_buffer()->place_cursor(iter_anchor);
-        _pCtMainWin->get_text_view().mm().scroll_to(_curr_buffer()->get_insert(), CtTextView::TEXT_SCROLL_MARGIN);
+        _pCtMainWin->get_text_view().set_selection_at_offset_n_delta(iter_anchor.get_offset(), 1);
     }
 }
 
