@@ -242,6 +242,7 @@ void CtConfig::_populate_keyfile_from_data()
     _uKeyFile->set_integer(_currentGroup, "nodes_on_node_name_header", nodesOnNodeNameHeader);
     _uKeyFile->set_integer(_currentGroup, "max_matches_in_page", maxMatchesInPage);
     _uKeyFile->set_integer(_currentGroup, "toolbar_icon_size", toolbarIconSize);
+    _uKeyFile->set_integer(_currentGroup, "search_multi_words", multipleWordsSearchType);
     if (not currColour_fg.empty()) _uKeyFile->set_string(_currentGroup, "fg", currColour_fg);
     if (not currColour_bg.empty()) _uKeyFile->set_string(_currentGroup, "bg", currColour_bg);
     if (not currColour_nn.empty()) _uKeyFile->set_string(_currentGroup, "nn", currColour_nn);
@@ -300,6 +301,7 @@ void CtConfig::_populate_keyfile_from_data()
     _uKeyFile->set_boolean(_currentGroup, "camelcase_autolink", camelCaseAutoLink);
     _uKeyFile->set_boolean(_currentGroup, "url_autolink", urlAutoLink);
     _uKeyFile->set_boolean(_currentGroup, "triple_click_paragraph", tripleClickParagraph);
+    _uKeyFile->set_boolean(_currentGroup, "double_click_link", doubleClickLink);
     _uKeyFile->set_boolean(_currentGroup, "enable_symbol_autoreplace", enableSymbolAutoreplace);
 #ifdef MD_AUTO_REPLACEMENT
     _uKeyFile->set_boolean(_currentGroup, "enable_md_formatting", enableMdFormatting);
@@ -526,6 +528,7 @@ void CtConfig::_populate_data_from_keyfile()
     _populate_int_from_keyfile("nodes_on_node_name_header", &nodesOnNodeNameHeader);
     _populate_int_from_keyfile("max_matches_in_page", &maxMatchesInPage);
     _populate_int_from_keyfile("toolbar_icon_size", &toolbarIconSize);
+    _populate_int_from_keyfile("search_multi_words", &multipleWordsSearchType);
     _populate_string_from_keyfile("fg", &currColour_fg);
     _populate_string_from_keyfile("bg", &currColour_bg);
     _populate_string_from_keyfile("nn", &currColour_nn);
@@ -615,6 +618,7 @@ void CtConfig::_populate_data_from_keyfile()
     _populate_bool_from_keyfile("camelcase_autolink", &camelCaseAutoLink);
     _populate_bool_from_keyfile("url_autolink", &urlAutoLink);
     _populate_bool_from_keyfile("triple_click_paragraph", &tripleClickParagraph);
+    _populate_bool_from_keyfile("double_click_link", &doubleClickLink);
     _populate_bool_from_keyfile("enable_symbol_autoreplace", &enableSymbolAutoreplace);
 #ifdef MD_AUTO_REPLACEMENT
     _populate_bool_from_keyfile("enable_md_formatting", &enableMdFormatting);
