@@ -83,6 +83,7 @@ public:
     int                                         nodesOnNodeNameHeader{3};
     int                                         maxMatchesInPage{500};
     int                                         toolbarIconSize{1};
+    int                                         multipleWordsSearchType{0}; // 0: exact match, 1: disregard order (AND), 2: match any (OR)
     Glib::ustring                               currColour_fg;
     Glib::ustring                               currColour_bg;
     Glib::ustring                               currColour_nn;
@@ -130,6 +131,7 @@ public:
     bool                                        urlAutoLink{true};
     bool                                        camelCaseAutoLink{true};
     bool                                        tripleClickParagraph{false};
+    bool                                        doubleClickLink{false};
     bool                                        enableSymbolAutoreplace{true};
 #ifdef MD_AUTO_REPLACEMENT
     bool                                        enableMdFormatting{false};
