@@ -265,7 +265,7 @@ const inline static gchar* TOOLBAR_VEC_DEFAULT {
     "separator,handle_image,handle_table,handle_codebox,handle_latex,handle_embfile,"
     "handle_link,handle_anchor,separator,fmt_clone,fmt_latest,fmt_rm,fmt_color_fg,"
     "fmt_color_bg,fmt_bold,fmt_italic,fmt_underline,fmt_strikethrough,"
-    "fmt_h1,fmt_h2,fmt_h3,fmt_small,fmt_superscript,fmt_subscript,fmt_monospace"
+    "fmt_h1,fmt_h2,fmt_h3,fmt_small,fmt_subscript,fmt_superscript,fmt_monospace"
 };
 
 const inline static gchar* LANG_DEFAULT{"default"};
@@ -691,7 +691,7 @@ const inline static Glib::ustring TARGET_URI_LIST = "text/uri-list";
 const inline static Glib::ustring TARGET_GTK_TEXT_BUFFER_CONTENTS = "GTK_TEXT_BUFFER_CONTENTS";
 const inline static std::vector<Glib::ustring> TARGETS_PLAIN_TEXT = {"UTF8_STRING", "COMPOUND_TEXT", "STRING", "TEXT", "text/plain;charset=utf-8", "text/plain"};
 const inline static std::vector<Glib::ustring> TARGETS_IMAGES = {"image/png", "image/jpeg", "image/bmp", "image/tiff", "image/x-MS-bmp", "image/x-bmp"};
-const inline static Glib::ustring TARGET_WINDOWS_FILE_NAME = "FileName";
+const inline static Glib::ustring TARGET_WINDOWS_URI_LIST_CF_HDROP = "CF_HDROP";
 const inline static Glib::ustring TAG_UL_START = "<ul>";
 const inline static Glib::ustring TAG_UL_END = "</ul>";
 const inline static Glib::ustring TAG_OL_START = "<ol>";
