@@ -1,7 +1,7 @@
 /*
  * ct_dialogs.cc
  *
- * Copyright 2009-2024
+ * Copyright 2009-2025
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -38,19 +38,23 @@ void CtDialogs::bookmarks_handle_dialog(CtMainWin* pCtMainWin)
     dialog.set_position(Gtk::WindowPosition::WIN_POS_CENTER_ON_PARENT);
     dialog.set_default_size(500, 400);
 
-    Glib::RefPtr<CtChooseDialogTreeStore> rModel = CtChooseDialogTreeStore::create();
-    for (const gint64& node_id : bookmarks)
-    {
-        rModel->add_row("ct_pin", "", ctTreestore.get_node_name_from_node_id(node_id), node_id);
+    Glib::RefPtr<CtChooseDialogTreeStore> pModel = CtChooseDialogTreeStore::create();
+    for (const gint64 node_id : bookmarks) {
+        CtTreeIter ct_tree_iter = ctTreestore.get_node_from_node_id(node_id);
+        const char* node_icon = ctTreestore.get_node_icon(
+            ctTreestore.get_store()->iter_depth(ct_tree_iter),
+            ct_tree_iter.get_node_syntax_highlighting(),
+            ct_tree_iter.get_node_custom_icon_id());
+        pModel->add_row(node_icon, "", ctTreestore.get_node_name_from_node_id(node_id), node_id);
     }
 
-    Gtk::TreeView treeview(rModel);
+    Gtk::TreeView treeview(pModel);
     treeview.set_headers_visible(false);
     treeview.set_reorderable(true);
     Gtk::CellRendererPixbuf pixbuf_renderer;
     int col_num = treeview.append_column("", pixbuf_renderer) - 1;
-    treeview.get_column(col_num)->add_attribute(pixbuf_renderer, "icon-name", rModel->columns.stock_id);
-    treeview.append_column("", rModel->columns.desc);
+    treeview.get_column(col_num)->add_attribute(pixbuf_renderer, "icon-name", pModel->columns.stock_id);
+    treeview.append_column("", pModel->columns.desc);
     Gtk::ScrolledWindow scrolledwindow;
     scrolledwindow.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
     scrolledwindow.add(treeview);
@@ -73,9 +77,8 @@ void CtDialogs::bookmarks_handle_dialog(CtMainWin* pCtMainWin)
     button_sort_asc.set_tooltip_text(_("Sort the Bookmarks Ascending"));
     Gtk::Label label1;
     Gtk::Label label2;
-    Gtk::HBox hbox;
-    Gtk::VBox vbox;
-    vbox.set_spacing(1);
+    Gtk::Box hbox{Gtk::ORIENTATION_HORIZONTAL};
+    Gtk::Box vbox{Gtk::ORIENTATION_VERTICAL, 1/*spacing*/};
     vbox.pack_start(button_move_up, false, false);
     vbox.pack_start(button_move_down, false, false);
     vbox.pack_start(button_delete, false, false);
@@ -88,20 +91,20 @@ void CtDialogs::bookmarks_handle_dialog(CtMainWin* pCtMainWin)
     pContentArea->pack_start(hbox);
     pContentArea->show_all();
 
-    treeview.signal_key_press_event().connect([&rModel, &treeview](GdkEventKey* key)->bool
+    treeview.signal_key_press_event().connect([&pModel, &treeview](GdkEventKey* key)->bool
     {
         if (key->keyval == GDK_KEY_Delete)
         {
-            Gtk::TreeIter tree_iter = treeview.get_selection()->get_selected();
+            Gtk::TreeModel::iterator tree_iter = treeview.get_selection()->get_selected();
             if (tree_iter)
             {
-                rModel->erase(tree_iter);
+                pModel->erase(tree_iter);
             }
             return true; // stop event
         }
         return false; // propagate event
     });
-    treeview.signal_button_press_event().connect([&treeview, &rModel, &pCtMainWin, &ctTreestore](GdkEventButton* event)->bool
+    treeview.signal_button_press_event().connect([&treeview, &pModel, &pCtMainWin, &ctTreestore](GdkEventButton* event)->bool
     {
         if (event->button != 1 || event->type != GDK_2BUTTON_PRESS)
         {
@@ -112,55 +115,55 @@ void CtDialogs::bookmarks_handle_dialog(CtMainWin* pCtMainWin)
         {
             return false; // propagate event
         }
-        Gtk::TreeIter clicked_iter = rModel->get_iter(clicked_path);
-        gint64 node_id = clicked_iter->get_value(rModel->columns.node_id);
-        Gtk::TreeIter tree_iter = ctTreestore.get_node_from_node_id(node_id);
+        Gtk::TreeModel::iterator clicked_iter = pModel->get_iter(clicked_path);
+        gint64 node_id = clicked_iter->get_value(pModel->columns.node_id);
+        Gtk::TreeModel::iterator tree_iter = ctTreestore.get_node_from_node_id(node_id);
         pCtMainWin->get_tree_view().set_cursor_safe(tree_iter);
         return true; // stop event
     });
-    button_move_up.signal_clicked().connect([&treeview, &rModel]()
+    button_move_up.signal_clicked().connect([&treeview, &pModel]()
     {
-        Gtk::TreeIter curr_iter = treeview.get_selection()->get_selected();
-        Gtk::TreeIter prev_iter = --treeview.get_selection()->get_selected();
+        Gtk::TreeModel::iterator curr_iter = treeview.get_selection()->get_selected();
+        Gtk::TreeModel::iterator prev_iter = --treeview.get_selection()->get_selected();
         if (curr_iter && prev_iter)
         {
-            rModel->iter_swap(curr_iter, prev_iter);
+            pModel->iter_swap(curr_iter, prev_iter);
         }
     });
-    button_move_down.signal_clicked().connect([&treeview, &rModel]()
+    button_move_down.signal_clicked().connect([&treeview, &pModel]()
     {
-        Gtk::TreeIter curr_iter = treeview.get_selection()->get_selected();
-        Gtk::TreeIter next_iter = ++treeview.get_selection()->get_selected();
+        Gtk::TreeModel::iterator curr_iter = treeview.get_selection()->get_selected();
+        Gtk::TreeModel::iterator next_iter = ++treeview.get_selection()->get_selected();
         if (curr_iter && next_iter)
         {
-            rModel->iter_swap(curr_iter, next_iter);
+            pModel->iter_swap(curr_iter, next_iter);
         }
     });
-    button_delete.signal_clicked().connect([&treeview, &rModel]()
+    button_delete.signal_clicked().connect([&treeview, &pModel]()
     {
-        Gtk::TreeIter tree_iter = treeview.get_selection()->get_selected();
+        Gtk::TreeModel::iterator tree_iter = treeview.get_selection()->get_selected();
         if (tree_iter)
         {
-            rModel->erase(tree_iter);
+            pModel->erase(tree_iter);
         }
     });
-    button_sort_asc.signal_clicked().connect([&rModel]()
+    button_sort_asc.signal_clicked().connect([&pModel]()
     {
-        auto need_swap = [&rModel](Gtk::TreeIter& l, Gtk::TreeIter& r)
+        auto need_swap = [&pModel](Gtk::TreeModel::iterator& l, Gtk::TreeModel::iterator& r)
         {
-            int cmp = l->get_value(rModel->columns.desc).compare(r->get_value(rModel->columns.desc));
+            int cmp = l->get_value(pModel->columns.desc).compare(r->get_value(pModel->columns.desc));
             return (cmp > 0);
         };
-        CtMiscUtil::node_siblings_sort(rModel, rModel->children(), need_swap);
+        CtMiscUtil::node_siblings_sort(pModel, pModel->children(), need_swap);
     });
-    button_sort_desc.signal_clicked().connect([&rModel]()
+    button_sort_desc.signal_clicked().connect([&pModel]()
     {
-        auto need_swap = [&rModel](Gtk::TreeIter& l, Gtk::TreeIter& r)
+        auto need_swap = [&pModel](Gtk::TreeModel::iterator& l, Gtk::TreeModel::iterator& r)
         {
-            int cmp = l->get_value(rModel->columns.desc).compare(r->get_value(rModel->columns.desc));
+            int cmp = l->get_value(pModel->columns.desc).compare(r->get_value(pModel->columns.desc));
             return (cmp < 0);
         };
-        CtMiscUtil::node_siblings_sort(rModel, rModel->children(), need_swap);
+        CtMiscUtil::node_siblings_sort(pModel, pModel->children(), need_swap);
     });
 
     if (dialog.run() != Gtk::RESPONSE_ACCEPT) {
@@ -169,9 +172,9 @@ void CtDialogs::bookmarks_handle_dialog(CtMainWin* pCtMainWin)
 
     std::set<gint64> temp_bookmarks;
     std::list<gint64> temp_bookmarks_order;
-    rModel->foreach_iter([&temp_bookmarks, &temp_bookmarks_order, &rModel](const Gtk::TreeIter& iter)
+    pModel->foreach_iter([&temp_bookmarks, &temp_bookmarks_order, &pModel](const Gtk::TreeModel::iterator& iter)
     {
-        gint64 node_id = iter->get_value(rModel->columns.node_id);
+        gint64 node_id = iter->get_value(pModel->columns.node_id);
         temp_bookmarks.insert(node_id);
         temp_bookmarks_order.push_back(node_id);
         return false; /* to continue */
@@ -254,7 +257,7 @@ bool CtDialogs::choose_data_storage_dialog(CtMainWin* pCtMainWin, CtStorageSelec
     Gtk::Label label_passwd(_("CT saves the document in an encrypted 7zip archive. When viewing or editing the document, CT extracts the encrypted archive to a temporary folder, and works on the unencrypted copy. When closing, the unencrypted copy is deleted from the temporary directory. Note that in the case of application or system crash, the unencrypted document will remain in the temporary folder."));
     label_passwd.set_width_chars(70);
     label_passwd.set_line_wrap(true);
-    Gtk::VBox vbox_passw;
+    Gtk::Box vbox_passw{Gtk::ORIENTATION_VERTICAL};
     vbox_passw.pack_start(entry_passw_1);
     vbox_passw.pack_start(entry_passw_2);
     vbox_passw.pack_start(label_passwd);
@@ -402,10 +405,9 @@ CtYesNoCancel CtDialogs::exit_save_dialog(CtMainWin& ct_main_win)
     image.set_from_icon_name("ct_warning", Gtk::ICON_SIZE_DIALOG);
     Gtk::Label label(Glib::ustring("<b>")+_("The Current Document was Updated.")+"</b>\n\n<b>"+_("Do you want to Save the Changes?")+"</b>");
     label.set_use_markup(true);
-    Gtk::HBox hbox;
+    Gtk::Box hbox{Gtk::ORIENTATION_HORIZONTAL, 5/*spacing*/};
     hbox.pack_start(image);
     hbox.pack_start(label);
-    hbox.set_spacing(5);
     Gtk::Box* pContentArea = dialog.get_content_area();
     pContentArea->pack_start(hbox);
     auto on_key_press_dialog = [&](GdkEventKey* pEventKey)->bool{
@@ -452,10 +454,9 @@ bool CtDialogs::exec_code_confirm_dialog(CtMainWin& ct_main_win,
     Gtk::Label label{Glib::ustring{"<b>"}+_("Do you want to Execute the Code?")+"</b>"};
     label.set_use_markup(true);
     Gtk::Label label_separator{" "};
-    Gtk::HBox hbox;
+    Gtk::Box hbox{Gtk::ORIENTATION_HORIZONTAL, 5/*spacing*/};
     hbox.pack_start(image);
     hbox.pack_start(label);
-    hbox.set_spacing(5);
     Gtk::Label code_preview;
     if (code_txt.size() < 200) {
         code_preview.set_markup(Glib::ustring{"<tt>"} + code_txt + "</tt>");
@@ -547,12 +548,12 @@ MA 02110-1301, USA.
  _("Chinese Traditional")+" (zh_TW) Emer Chen <ldsemerchen@gmail.com>"+CtConst::CHAR_NEWLINE+
  _("Croatian")+" (hr) Filip Bakula <filip.test46@gmail.com>"+CtConst::CHAR_NEWLINE+
  _("Czech")+" (cs) Pavel Fric <fripohled@blogspot.com>"+CtConst::CHAR_NEWLINE+
- _("Dutch")+" (nl) Luuk Geurts"+CtConst::CHAR_NEWLINE+
- _("Finnish")+" (fi) Henri Kaustinen <hendrix.ks81@gmail.com>"+CtConst::CHAR_NEWLINE+
+ _("Dutch")+" (nl) "+CtConst::CHAR_NEWLINE+
+ _("Finnish")+" (fi) "+CtConst::CHAR_NEWLINE+
  _("French")+" (fr) Francis Gernet <fgernet@concretx.com>"+CtConst::CHAR_NEWLINE+
- _("German")+" (de) Matthias Hoffmann <MHoffi@web.de>"+CtConst::CHAR_NEWLINE+
+ _("German")+" (de) Mr.Update"+CtConst::CHAR_NEWLINE+
  _("Greek")+" (el) Asterios Siomos <terry.sio@hotmail.com>"+CtConst::CHAR_NEWLINE+
- _("Hindi India")+" (hi_IN) Paresh Mhatre <pareshmhatrework@gmail.com>"+CtConst::CHAR_NEWLINE+
+ _("Hindi India")+" (hi_IN) "+CtConst::CHAR_NEWLINE+
  _("Hungarian")+" (hu) Stiener Norbert <stienernorbert@protonmail.com>"+CtConst::CHAR_NEWLINE+
  _("Italian")+" (it) Vincenzo Reale <smart2128vr@gmail.com>"+CtConst::CHAR_NEWLINE+
  _("Japanese")+" (ja) Piyo <py2@live.jp>"+CtConst::CHAR_NEWLINE+
@@ -568,7 +569,7 @@ MA 02110-1301, USA.
  _("Russian")+" (ru) Viktor Polyanskiy <camilot55@yandex.ru>"+CtConst::CHAR_NEWLINE+
  _("Slovak")+" (sk) Michal Fusatý <fusaty@proton.me>"+CtConst::CHAR_NEWLINE+
  _("Slovenian")+" (sl) Erik Lovrič <erik.lovric@gmail.com>"+CtConst::CHAR_NEWLINE+
- _("Spanish")+" (es) UserFav <userfav.post@gmail.com>"+CtConst::CHAR_NEWLINE+
+ _("Spanish")+" (es) MP"+CtConst::CHAR_NEWLINE+
  _("Swedish")+" (sv) Åke Engelbrektson <eson@svenskasprakfiler.se>"+CtConst::CHAR_NEWLINE+
  _("Turkish")+" (tr) Ferhat Aydin <ferhataydin44@gmail.com>"+CtConst::CHAR_NEWLINE+
  _("Ukrainian")+" (uk) Giuseppe Penone <giuspen@gmail.com>");
