@@ -31,6 +31,7 @@
 
 class CtMainWin;
 class CtTreeStore;
+struct CtNodeData;
 
 class CtDialogTextEntry : public Gtk::Dialog
 {
@@ -161,7 +162,7 @@ private:
     CtMatchDialogStore(const size_t maxMatchesInPage)
      : cMaxMatchesInPage{maxMatchesInPage}
     {}
-    Gtk::TreeIter _add_row(const CtMatchRowData& row_data);
+    Gtk::TreeModel::iterator _add_row(const CtMatchRowData& row_data);
 
     int                         _page_idx{0};
     std::vector<CtMatchRowData> _all_matches;
@@ -169,12 +170,13 @@ private:
 
 namespace CtDialogs {
 
-Gtk::TreeIter choose_item_dialog(Gtk::Window& parent,
+Gtk::TreeModel::iterator choose_item_dialog(Gtk::Window& parent,
                                  const Glib::ustring& title,
                                  Glib::RefPtr<CtChooseDialogListStore> model,
                                  const gchar* single_column_name = nullptr,
                                  const std::string& pathToSelect = "0",
-                                 std::optional<std::pair<int,int>> use_size = std::nullopt);
+                                 std::optional<std::pair<int,int>> use_size = std::nullopt,
+                                 const bool column_is_colour = false);
 
 // Dialog to select between the Selected Node/Selected Node + Subnodes/All Tree
 CtExporting selnode_selnodeandsub_alltree_dialog(Gtk::Window& parent,
@@ -185,7 +187,7 @@ CtExporting selnode_selnodeandsub_alltree_dialog(Gtk::Window& parent,
                                                  bool* last_single_file);
 
 // Dialog to select a color, featuring a palette
-enum class CtPickDlgState {SELECTED, CANCEL, REMOVE_COLOR };
+enum class CtPickDlgState {SELECTED, CANCEL, REMOVE_COLOR, CALL_AGAIN };
 CtPickDlgState colour_pick_dialog(CtMainWin* pCtMainWin, const Glib::ustring& title,
                                   Glib::ustring& colour, bool allow_remove_colour);
 
@@ -206,11 +208,11 @@ void error_dialog(const Glib::ustring& message,
                   Gtk::Window& parent);
 
 // Dialog to Select a Node
-Gtk::TreeIter choose_node_dialog(CtMainWin* pCtMainWin,
+Gtk::TreeModel::iterator choose_node_dialog(CtMainWin* pCtMainWin,
                                  Gtk::TreeView& parentTreeView,
                                  const Glib::ustring& title,
                                  CtTreeStore* treestore,
-                                 Gtk::TreeIter sel_tree_iter);
+                                 Gtk::TreeModel::iterator sel_tree_iter);
 
 // Handle the Bookmarks List
 void bookmarks_handle_dialog(CtMainWin* pCtMainWin);
@@ -247,8 +249,8 @@ Glib::ustring img_n_entry_dialog(Gtk::Window& parent,
 // Dialog to Insert/Edit Links
 bool link_handle_dialog(CtMainWin& ctMainWin,
                         const Glib::ustring& title,
-                        Gtk::TreeIter sel_tree_iter,
-                        CtLinkEntry& link_entries);
+                        Gtk::TreeModel::iterator sel_tree_iter,
+                        CtLinkEntry& link_entry);
 
 struct CtFileSelectArgs
 {
@@ -305,7 +307,7 @@ bool exec_code_confirm_dialog(CtMainWin& ct_main_win,
 void dialog_about(Gtk::Window& parent, Glib::RefPtr<Gdk::Pixbuf> icon);
 
 std::string dialog_palette(CtMainWin* pCtMainWin);
-gint64 dialog_selnode(CtMainWin* pCtMainWin);
+gint64 dialog_selnode(CtMainWin* pCtMainWin, const Glib::ustring& entryStr);
 
 void summary_info_dialog(CtMainWin* pCtMainWin, const CtSummaryInfo& summaryInfo);
 
