@@ -1,7 +1,7 @@
 /*
  * ct_export2pdf.cc
  *
- * Copyright 2009-2024
+ * Copyright 2009-2025
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -189,8 +189,6 @@ void CtExport2Pango::_pango_text_serialize(const Gtk::TextIter& start_iter,
                                            std::vector<CtPangoObjectPtr>& out_slots)
 {
     Glib::ustring pango_attrs;
-    bool superscript_active{false};
-    bool subscript_active{false};
     int indent{0};
     std::string link_url;
     for (auto tag_property : CtConst::TAG_PROPERTIES) {
@@ -202,11 +200,11 @@ void CtExport2Pango::_pango_text_serialize(const Gtk::TextIter& start_iter,
             // tag names fix
             if (tag_property == CtConst::TAG_SCALE) {
                 if (property_value == CtConst::TAG_PROP_VAL_SUP) {
-                    superscript_active = true;
+                    pango_attrs += " size=\"xx-small\" rise=\"5000\"";
                     continue;
                 }
                 if (property_value == CtConst::TAG_PROP_VAL_SUB) {
-                    subscript_active = true;
+                    pango_attrs += " size=\"xx-small\" rise=\"-5000\"";
                     continue;
                 }
                 size_t sIdx;
@@ -293,12 +291,10 @@ void CtExport2Pango::_pango_text_serialize(const Gtk::TextIter& start_iter,
 
                 auto untagged_slot = -1 == delta_inversion ? lines[i].raw().substr(j) : lines[i].raw().substr(j, static_cast<size_t>(delta_inversion));
                 Glib::ustring tagged_text = str::xml_escape(untagged_slot);
+
                 if (not pango_attrs.empty())
                     tagged_text = "<span" + pango_attrs + ">" + tagged_text + "</span>";
 
-                if (superscript_active) tagged_text = "<sup>" + tagged_text + "</sup>";
-                if (subscript_active) tagged_text = "<sub>" + tagged_text + "</sub>";
-
                 if (not link_url.empty()) {
                     out_slots.emplace_back(_pango_link_url(tagged_text, link_url, indent, pango_dir));
                     //spdlog::debug("PANGO link={} indent={} pango_dir={}", tagged_text, indent, pango_dir);
@@ -330,18 +326,18 @@ void CtExport2Pango::_pango_text_serialize(const Gtk::TextIter& start_iter,
 
 std::shared_ptr<CtPangoText> CtExport2Pango::_pango_link_url(const Glib::ustring& tagged_text, const Glib::ustring& link, const int indent, const PangoDirection pango_dir)
 {
-    CtLinkEntry link_entry = CtMiscUtil::get_link_entry(link);
+    CtLinkEntry link_entry = CtMiscUtil::get_link_entry_from_property(link);
     Glib::ustring uri;
-    if (link_entry.type == CtConst::LINK_TYPE_NODE) {
+    if (CtLinkType::Node == link_entry.type) {
         uri = "dest='" + generate_tag(link_entry.node_id, link_entry.anch) + "'";
     }
-    else if (link_entry.type == CtConst::LINK_TYPE_WEBS) {
+    else if (CtLinkType::Webs == link_entry.type) {
         uri = "uri='" + str::xml_escape(link_entry.webs) + "'";
     }
-    else if (link_entry.type == CtConst::LINK_TYPE_FILE or
-             link_entry.type == CtConst::LINK_TYPE_FOLD)
+    else if (CtLinkType::File == link_entry.type or
+             CtLinkType::Fold == link_entry.type)
     {
-        std::string fileOrFold = link_entry.type == CtConst::LINK_TYPE_FILE ? link_entry.file.raw() : link_entry.fold.raw();
+        std::string fileOrFold = CtLinkType::File == link_entry.type ? link_entry.file.raw() : link_entry.fold.raw();
 #if defined(_WIN32) || defined(__APPLE__)
         const std::string encoding = CtStrUtil::get_encoding(fileOrFold.c_str(), fileOrFold.size());
         if (encoding == "ASCII") {
@@ -365,8 +361,8 @@ std::shared_ptr<CtPangoText> CtExport2Pango::_pango_link_url(const Glib::ustring
 
 void CtExport2Pdf::node_export_print(const fs::path& pdf_filepath, CtTreeIter tree_iter, const CtExportOptions& options, int sel_start, int sel_end)
 {
-    Glib::RefPtr<Gtk::TextBuffer> rTextBuffer = tree_iter.get_node_text_buffer();
-    if (not rTextBuffer) {
+    Glib::RefPtr<Gtk::TextBuffer> pTextBuffer = tree_iter.get_node_text_buffer();
+    if (not pTextBuffer) {
         throw std::runtime_error(str::format(_("Failed to retrieve the content of the node '%s'"), tree_iter.get_node_name().raw()));
     }
     std::vector<CtPangoObjectPtr> pango_slots;
@@ -375,7 +371,7 @@ void CtExport2Pdf::node_export_print(const fs::path& pdf_filepath, CtTreeIter tr
     }
     else {
         Glib::ustring text = CtExport2Pango{_pCtMainWin}.pango_get_from_code_buffer(
-            rTextBuffer, sel_start, sel_end, tree_iter.get_node_syntax_highlighting());
+            pTextBuffer, sel_start, sel_end, tree_iter.get_node_syntax_highlighting());
         pango_slots.push_back(std::make_shared<CtPangoText>(text, tree_iter.get_node_syntax_highlighting(), 0/*indent*/, PANGO_DIRECTION_LTR));
     }
 
@@ -407,8 +403,8 @@ void CtExport2Pdf::_nodes_all_export_print_iter(CtTreeIter tree_iter,
                                                 const CtExportOptions& options,
                                                 std::vector<CtPangoObjectPtr>& tree_pango_slots)
 {
-    Glib::RefPtr<Gtk::TextBuffer> rTextBuffer = tree_iter.get_node_text_buffer();
-    if (not rTextBuffer) {
+    Glib::RefPtr<Gtk::TextBuffer> pTextBuffer = tree_iter.get_node_text_buffer();
+    if (not pTextBuffer) {
         throw std::runtime_error(str::format(_("Failed to retrieve the content of the node '%s'"), tree_iter.get_node_name().raw()));
     }
     std::vector<CtPangoObjectPtr> node_pango_slots;
@@ -417,7 +413,7 @@ void CtExport2Pdf::_nodes_all_export_print_iter(CtTreeIter tree_iter,
     }
     else {
         Glib::ustring text = CtExport2Pango{_pCtMainWin}.pango_get_from_code_buffer(
-            rTextBuffer, -1, -1, tree_iter.get_node_syntax_highlighting());
+            pTextBuffer, -1, -1, tree_iter.get_node_syntax_highlighting());
         node_pango_slots.push_back(std::make_shared<CtPangoText>(text, tree_iter.get_node_syntax_highlighting(), 0/*indent*/, PANGO_DIRECTION_LTR));
     }
 
@@ -728,6 +724,7 @@ void CtPrint::_process_pango_text(CtPrintData* print_data, CtPangoText* text_slo
         layout->set_indent(int(pages.last_line().cur_x * Pango::SCALE));
     }
     layout->set_markup(text_slot->text);
+    //spdlog::debug("{}", text_slot->text.c_str());
 
     int layout_count = layout->get_line_count();
     for (int i = 0; i < layout_count; ++i) {
@@ -1028,13 +1025,15 @@ void CtPrint::_codebox_split_content(const CtCodebox* codebox,
                                      const int codebox_width)
 {
     std::vector<Glib::ustring> original_splitted_pango = str::split(original_content, "\n");
-    // fix for not-closed span, I suppose
-    for (size_t i = 0; i < original_splitted_pango.size(); ++i) {
-        auto& element = original_splitted_pango[i];
+    // fix for not-closed span
+    const size_t original_splitted_pango_size = original_splitted_pango.size();
+    for (size_t i = 0u; i < original_splitted_pango_size; ++i) {
+        Glib::ustring& element = original_splitted_pango[i];
+        //if (0u == i) spdlog::debug("{}", element.c_str());
         Glib::ustring::size_type last_close = element.rfind("</span");
         Glib::ustring::size_type last_open = element.rfind("<span");
         if (last_close < element.size() and last_open < element.size() and last_close < last_open) {
-            auto non_closed_span = element.substr(last_open);
+            Glib::ustring non_closed_span = element.substr(last_open);
             Glib::ustring::size_type end_non_closed_span_idx = non_closed_span.find(">");
             if (end_non_closed_span_idx < non_closed_span.size()) {
                 non_closed_span = non_closed_span.substr(0, end_non_closed_span_idx+1);
@@ -1045,20 +1044,20 @@ void CtPrint::_codebox_split_content(const CtCodebox* codebox,
     }
 
     std::vector<Glib::ustring> splitted_pango;
-    while (splitted_pango.size() < original_splitted_pango.size()) {
+    while (splitted_pango.size() < original_splitted_pango_size) {
         splitted_pango.push_back(original_splitted_pango[splitted_pango.size()]);
         Glib::ustring new_content = str::join(splitted_pango, CtConst::CHAR_NEWLINE);
-        auto codebox_layout = _codebox_get_layout(codebox, new_content, context, codebox_width);
-        double codebox_height = _get_height_from_layout(codebox_layout);
-        if (codebox_height + BOX_OFFSET > check_height) {
-            if (splitted_pango.size() == 1) {
+        Glib::RefPtr<Pango::Layout> codebox_layout = _codebox_get_layout(codebox, new_content, context, codebox_width);
+        const double codebox_height = _get_height_from_layout(codebox_layout);
+        if ((codebox_height + BOX_OFFSET) > check_height) {
+            if (1u == splitted_pango.size()) {
                 // check_height is not enough, so we need a new page
-                first_split = "";
+                first_split.clear();
                 second_split = original_content;
                 return;
             }
 
-            splitted_pango.erase(splitted_pango.end());
+            splitted_pango.pop_back();
             original_splitted_pango.erase(original_splitted_pango.begin(), original_splitted_pango.begin() + splitted_pango.size());
             first_split = str::join(splitted_pango, CtConst::CHAR_NEWLINE);
             second_split = str::join(original_splitted_pango, CtConst::CHAR_NEWLINE);
