@@ -1,7 +1,7 @@
 /*
  * ct_imports.cc
  *
- * Copyright 2009-2023
+ * Copyright 2009-2024
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -384,7 +384,7 @@ void CtTomboyImport::_iterate_tomboy_note(xmlpp::Element* iter, std::unique_ptr<
                 _is_link_to_node = false;
             }
             else {
-                spdlog::debug(dom_iter->get_name());
+                spdlog::debug(dom_iter->get_name().raw());
                 _iterate_tomboy_note(dom_iter_el, node);
             }
         }
@@ -440,19 +440,20 @@ CtMDImport::~CtMDImport() = default;
 
 std::unique_ptr<CtImportedNode> CtPlainTextImport::import_file(const fs::path& file)
 {
-    if (!CtMiscUtil::mime_type_contains(file.string(), "text/")) {
+    if (not CtMiscUtil::mime_type_contains(file.string(), "text/")) {
         return nullptr;
     }
     try {
-        std::string converted = Glib::file_get_contents(file.string());
-        CtStrUtil::convert_if_not_utf8(converted, true/*sanitise*/);
-        auto node = std::make_unique<CtImportedNode>(file, file.stem());
-        node->xml_content->create_root_node("root")->add_child("slot")->add_child("rich_text")->add_child_text(converted);
-        node->node_syntax = CtConst::PLAIN_TEXT_ID;
-        return node;
+        Glib::ustring utf8_text;
+        if (CtStrUtil::file_any_encoding_to_utf8(file.string(), utf8_text)) {
+            auto pNode = std::make_unique<CtImportedNode>(file, file.stem());
+            pNode->xml_content->create_root_node("root")->add_child("slot")->add_child("rich_text")->add_child_text(utf8_text);
+            pNode->node_syntax = CtConst::PLAIN_TEXT_ID;
+            return pNode;
+        }
     }
     catch (std::exception& ex) {
-        spdlog::error("{}, what: {}, file: {}", __FUNCTION__, ex.what(), file);
+        spdlog::error("{}, what: {}, file: {}", __FUNCTION__, ex.what(), file.string());
     }
     return nullptr;
 }
