@@ -1,7 +1,7 @@
 /*
  * ct_main_win_events.cc
  *
- * Copyright 2009-2024
+ * Copyright 2009-2025
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -41,21 +41,21 @@ void CtMainWin::_on_treeview_cursor_changed()
             return;
         }
         const gint64 prevNodeIdDataHolder = _prevTreeIter.get_node_id_data_holder();
-        Glib::RefPtr<Gtk::TextBuffer> rTextBuffer = _prevTreeIter.get_node_text_buffer();
-        if (rTextBuffer->get_modified()) {
+        Glib::RefPtr<Gtk::TextBuffer> pTextBuffer = _prevTreeIter.get_node_text_buffer();
+        if (pTextBuffer->get_modified()) {
             _fileSaveNeeded = true;
-            rTextBuffer->set_modified(false);
+            pTextBuffer->set_modified(false);
             _ctStateMachine.update_state(_prevTreeIter);
         }
         const int scr = round(_scrolledwindowText.get_vadjustment()->get_value());
-        const int cur = rTextBuffer->property_cursor_position();
+        const int cur = pTextBuffer->property_cursor_position();
         _nodesVScrollPos[prevNodeIdDataHolder] = scr;
         _nodesCursorPos[prevNodeIdDataHolder] = cur;
         //spdlog::debug("W[{}] scr={}, cur={}", prevNodeIdDataHolder, scr, cur);
     }
 
-    Glib::RefPtr<Gtk::TextBuffer> rTextBuffer = treeIter.get_node_text_buffer();
-    if (not rTextBuffer) {
+    Glib::RefPtr<Gtk::TextBuffer> pTextBuffer = treeIter.get_node_text_buffer();
+    if (not pTextBuffer) {
         CtDialogs::error_dialog(str::format(_("Failed to retrieve the content of the node '%s'"), treeIter.get_node_name().raw()), *this);
         if (_prevTreeIter) {
             _uCtTreeview->set_cursor_safe(_prevTreeIter);
@@ -187,32 +187,32 @@ bool CtMainWin::_on_treeview_key_press_event(GdkEventKey* event)
     if (event->state & GDK_MOD1_MASK) {
     }
     else if (event->state & GDK_CONTROL_MASK) {
-        auto reduce = [](Gtk::TreeIter first, std::function<Gtk::TreeIter(Gtk::TreeIter)> operatr)->Gtk::TreeIter{
-            Gtk::TreeIter result;
+        auto reduce = [](Gtk::TreeModel::iterator first, std::function<Gtk::TreeModel::iterator(Gtk::TreeModel::iterator)> operatr)->Gtk::TreeModel::iterator{
+            Gtk::TreeModel::iterator result;
             for (auto next = operatr(first); next; next = operatr(next))
                 result = next;
             return result;
         };
         if (GDK_KEY_Up == event->keyval) {
-            auto fist_sibling = reduce(curr_tree_iter(), [](Gtk::TreeIter iter) { return --iter;});
+            auto fist_sibling = reduce(curr_tree_iter(), [](Gtk::TreeModel::iterator iter) { return --iter;});
             if (fist_sibling)
                 get_tree_view().set_cursor_safe(fist_sibling);
             return true;
         }
         if (GDK_KEY_Down == event->keyval) {
-            auto last_sibling = reduce(curr_tree_iter(), [](Gtk::TreeIter iter) { return ++iter;});
+            auto last_sibling = reduce(curr_tree_iter(), [](Gtk::TreeModel::iterator iter) { return ++iter;});
             if (last_sibling)
                 get_tree_view().set_cursor_safe(last_sibling);
             return true;
         }
         if (GDK_KEY_Left == event->keyval) {
-            auto fist_parent = reduce(curr_tree_iter(), [](Gtk::TreeIter iter) { return iter->parent();});
+            auto fist_parent = reduce(curr_tree_iter(), [](Gtk::TreeModel::iterator iter) { return iter->parent();});
             if (fist_parent)
                 get_tree_view().set_cursor_safe(fist_parent);
             return true;
         }
         if (GDK_KEY_Right == event->keyval) {
-            auto last_child = reduce(curr_tree_iter(), [](Gtk::TreeIter iter) { return iter->children().begin();});
+            auto last_child = reduce(curr_tree_iter(), [](Gtk::TreeModel::iterator iter) { return iter->children().begin();});
             if (last_child)
                 get_tree_view().set_cursor_safe(last_child);
             return true;
@@ -262,6 +262,14 @@ bool CtMainWin::_on_treeview_key_press_event(GdkEventKey* event)
             _uCtActions->node_delete();
             return true;
         }
+        {
+            const gunichar unicode_char = gdk_keyval_to_unicode(event->keyval);
+            if (unicode_char != 0 && g_unichar_isalnum(unicode_char)) {
+                Glib::ustring entryStr{1, unicode_char};
+                _uCtActions->command_selnode_str(entryStr);
+                return true;
+            }
+        }
     }
     return false;
 }
@@ -328,16 +336,18 @@ void CtMainWin::_on_textview_populate_popup(Gtk::Menu* menu)
 // Update the cursor image if the pointer moved
 bool CtMainWin::_on_textview_motion_notify_event(GdkEventMotion* event)
 {
-    if (not _ctTextview.mm().get_cursor_visible())
-        _ctTextview.mm().set_cursor_visible(true);
-    if (curr_tree_iter().get_node_syntax_highlighting() != CtConst::RICH_TEXT_ID
-        and curr_tree_iter().get_node_syntax_highlighting() != CtConst::PLAIN_TEXT_ID)
-    {
-        _ctTextview.mm().get_window(Gtk::TEXT_WINDOW_TEXT)->set_cursor(Gdk::Cursor::create(Gdk::XTERM));
+    Gtk::TextView& textView = _ctTextview.mm();
+    if (not textView.get_cursor_visible()) {
+        textView.set_cursor_visible(true);
+    }
+    //textView.reset_cursor_blink();
+    CtTreeIter ctTreeIter = curr_tree_iter();
+    if (ctTreeIter.get_node_is_code()) {
+        textView.get_window(Gtk::TEXT_WINDOW_TEXT)->set_cursor(Gdk::Cursor::create(Gdk::XTERM));
         return false;
     }
     int x, y;
-    _ctTextview.mm().window_to_buffer_coords(Gtk::TEXT_WINDOW_TEXT, (int)event->x, (int)event->y, x, y);
+    textView.window_to_buffer_coords(Gtk::TEXT_WINDOW_TEXT, (int)event->x, (int)event->y, x, y);
     _ctTextview.cursor_and_tooltips_handler(x, y);
     return false;
 }
@@ -516,11 +526,11 @@ bool CtMainWin::_on_textview_event(GdkEvent* event)
 // Called after every event on the SourceView
 void CtMainWin::_on_textview_event_after(GdkEvent* event)
 {
-    if (event->type == GDK_2BUTTON_PRESS and event->button.button == 1) {
-        _ctTextview.for_event_after_double_click_button1(event);
+    if (event->type == GDK_2BUTTON_PRESS and (1 == event->button.button or 2 == event->button.button)) {
+        _ctTextview.for_event_after_double_click_button12(event);
     }
-    if (event->type == GDK_3BUTTON_PRESS and event->button.button == 1) {
-        _ctTextview.for_event_after_triple_click_button1(event);
+    if (event->type == GDK_3BUTTON_PRESS and (1 == event->button.button or 2 == event->button.button)) {
+        _ctTextview.for_event_after_triple_click_button12(event);
     }
     else if (event->type == GDK_BUTTON_PRESS or event->type == GDK_KEY_PRESS) {
         if (event->type == GDK_BUTTON_PRESS) {
@@ -629,7 +639,7 @@ void CtMainWin::_on_treeview_drag_data_get(const Glib::RefPtr<Gdk::DragContext>&
                                            guint /*info*/,
                                            guint /*time*/)
 {
-    Gtk::TreeIter sel_iter = _uCtTreeview->get_selection()->get_selected();
+    Gtk::TreeModel::iterator sel_iter = _uCtTreeview->get_selection()->get_selected();
     if (sel_iter) {
         const Glib::ustring treePathStr = _uCtTreeview->get_model()->get_path(sel_iter).to_string();
         selection_data.set("UTF8_STRING", 8, (const guint8*)treePathStr.c_str(), (int)treePathStr.size());
