@@ -1,7 +1,7 @@
 /*
  * ct_menu_ui.cc
  *
- * Copyright 2009-2024
+ * Copyright 2009-2025
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -257,8 +257,8 @@ const char* CtMenu::_get_ui_str_menu()
       <menuitem action='fmt_strikethrough'/>
       <menuitem action='fmt_monospace'/>
       <menuitem action='fmt_small'/>
-      <menuitem action='fmt_superscript'/>
       <menuitem action='fmt_subscript'/>
+      <menuitem action='fmt_superscript'/>
     </menu>
     <menu action='ChangeCaseSubMenu'>
       <menuitem action='case_down'/>
@@ -277,6 +277,9 @@ const char* CtMenu::_get_ui_str_menu()
     <menuitem action='fmt_indent'/>
     <menuitem action='fmt_unindent'/>
     <separator/>
+    <menuitem action='head_expand'/>
+    <menuitem action='head_collapse'/>
+    <separator/>
     <menu action='JustifySubMenu'>
       <menuitem action='fmt_justify_left'/>
       <menuitem action='fmt_justify_center'/>
@@ -376,6 +379,9 @@ const char* CtMenu::_get_ui_str_menu()
     <separator/>
     <menuitem action='toolbar_icons_size_p'/>
     <menuitem action='toolbar_icons_size_m'/>
+    <separator/>
+    <menuitem action='more_visit_nnh'/>
+    <menuitem action='less_visit_nnh'/>
   </menu>
 
   <menu action='BookmarksMenu'>
@@ -428,8 +434,8 @@ const char* CtMenu::_get_popup_menu_ui_str_text()
       <menuitem action='fmt_strikethrough'/>
       <menuitem action='fmt_monospace'/>
       <menuitem action='fmt_small'/>
-      <menuitem action='fmt_superscript'/>
       <menuitem action='fmt_subscript'/>
+      <menuitem action='fmt_superscript'/>
     </menu>
       <menu action='ChangeCaseSubMenu'>
       <menuitem action='case_down'/>
@@ -448,6 +454,9 @@ const char* CtMenu::_get_popup_menu_ui_str_text()
     <menuitem action='fmt_indent'/>
     <menuitem action='fmt_unindent'/>
     <separator/>
+    <menuitem action='head_expand'/>
+    <menuitem action='head_collapse'/>
+    <separator/>
     <menu action='JustifySubMenu'>
       <menuitem action='fmt_justify_left'/>
       <menuitem action='fmt_justify_center'/>
