@@ -224,27 +224,108 @@ Gtk::BuiltinIconSize CtMiscUtil::getIconSize(int size)
     }
 }
 
-CtLinkEntry CtMiscUtil::get_link_entry(const Glib::ustring& link)
+CtLinkEntry CtMiscUtil::get_link_entry_from_property(const Glib::ustring& link)
 {
-    CtLinkEntry link_entry;
-    auto vec = str::split(link, " ");
-    if (vec.empty()) return CtLinkEntry();
-    link_entry.type = vec[0];
-    if (link_entry.type == CtConst::LINK_TYPE_WEBS)        link_entry.webs = vec[1];
-    else if (link_entry.type == CtConst::LINK_TYPE_FILE)   link_entry.file = Glib::Base64::decode(vec[1]);
-    else if (link_entry.type == CtConst::LINK_TYPE_FOLD)   link_entry.fold = Glib::Base64::decode(vec[1]);
-    else if (link_entry.type == CtConst::LINK_TYPE_NODE) {
-        link_entry.node_id = std::stol(vec[1]);
-        if (vec.size() >= 3) {
-            if (vec.size() == 3) link_entry.anch = vec[2];
-            else                 link_entry.anch = link.substr(vec[0].size() + vec[1].size() + 2);
+    CtLinkEntry link_entry{};
+    std::vector<Glib::ustring> link_vec = str::split(link, " ");
+    if (link_vec.empty()) return link_entry;
+    if (CtConst::LINK_TYPE_WEBS == link_vec[0]) {
+        link_entry.type = CtLinkType::Webs;
+        link_entry.webs = link_vec[1];
+    }
+    else if (CtConst::LINK_TYPE_FILE == link_vec[0]) {
+        link_entry.type = CtLinkType::File;
+        link_entry.file = Glib::Base64::decode(link_vec[1]);
+    }
+    else if (CtConst::LINK_TYPE_FOLD == link_vec[0]) {
+        link_entry.type = CtLinkType::Fold;
+        link_entry.fold = Glib::Base64::decode(link_vec[1]);
+    }
+    else if (CtConst::LINK_TYPE_NODE == link_vec[0]) {
+        link_entry.type = CtLinkType::Node;
+        link_entry.node_id = std::stol(link_vec[1]);
+        if (link_vec.size() >= 3) {
+            if (link_vec.size() == 3) link_entry.anch = link_vec[2];
+            else link_entry.anch = link.substr(link_vec[0].size() + link_vec[1].size() + 2);
         }
-    } else {
-        return CtLinkEntry();
     }
     return link_entry;
 }
 
+Glib::ustring CtMiscUtil::get_link_property_from_entry(const CtLinkEntry& link_entry)
+{
+    Glib::ustring property_value;
+    if (CtLinkType::Webs == link_entry.type) {
+        std::string link_url = link_entry.webs;
+        if (not link_url.empty()) {
+            if (not str::startswith_url(link_url.c_str())) {
+                link_url = "http://" + link_url;
+            }
+            property_value = CtConst::LINK_TYPE_WEBS + CtConst::CHAR_SPACE + link_url;
+        }
+    }
+    else if (CtLinkType::File == link_entry.type or CtLinkType::Fold == link_entry.type) {
+        Glib::ustring link_uri = CtLinkType::File == link_entry.type ? link_entry.file : link_entry.fold;
+        if (not link_uri.empty()) {
+            link_uri = Glib::Base64::encode(link_uri);
+            property_value = link_entry.get_type_str() + CtConst::CHAR_SPACE + link_uri;
+        }
+    }
+    else if (CtLinkType::Node == link_entry.type) {
+        gint64 node_id = link_entry.node_id;
+        if (node_id != -1) {
+            auto link_anchor = link_entry.anch;
+            property_value = CtConst::LINK_TYPE_NODE + CtConst::CHAR_SPACE + std::to_string(node_id);
+            if (not link_anchor.empty()) property_value += CtConst::CHAR_SPACE + link_anchor;
+        }
+    }
+    return property_value;
+}
+
+// Check if the cursor is on a link, in this case select the link and return the tag_property_value
+Glib::ustring CtMiscUtil::link_check_around_cursor(Glib::RefPtr<Gtk::TextBuffer> pTextBuffer, std::optional<Gtk::TextIter> optTextIter/*= std::nullopt*/)
+{
+    auto link_check_around_cursor_iter = [](Gtk::TextIter text_iter)->Glib::ustring{
+        auto tags = text_iter.get_tags();
+        for (auto& tag : tags) {
+            Glib::ustring tag_name = tag->property_name();
+            if (str::startswith(tag_name, CtConst::TAG_LINK)) {
+                return tag_name;
+            }
+        }
+        return "";
+    };
+    Gtk::TextIter text_iter = optTextIter.has_value() ? optTextIter.value() : pTextBuffer->get_insert()->get_iter();
+    Glib::ustring tag_name = link_check_around_cursor_iter(text_iter);
+    if (tag_name.empty()) {
+        if (text_iter.get_char() == ' ' and text_iter.backward_char()) {
+            tag_name = link_check_around_cursor_iter(text_iter);
+            if (tag_name.empty()) return "";
+        }
+        else {
+            return "";
+        }
+    }
+    auto iter_end = text_iter;
+    while (iter_end.forward_char()) {
+        Glib::ustring ret_tag_name = link_check_around_cursor_iter(iter_end);
+        if (ret_tag_name != tag_name) {
+            break;
+        }
+    }
+    while (text_iter.backward_char()) {
+        Glib::ustring ret_tag_name = link_check_around_cursor_iter(text_iter);
+        if (ret_tag_name != tag_name) {
+            text_iter.forward_char();
+            break;
+        }
+    }
+    if (text_iter == iter_end) return "";
+    pTextBuffer->move_mark(pTextBuffer->get_insert(), iter_end);
+    pTextBuffer->move_mark(pTextBuffer->get_selection_bound(), text_iter);
+    return tag_name.substr(5);
+}
+
 bool CtMiscUtil::mime_type_contains(const std::string &filepath, const char* type)
 {
     GFile* pGFile = g_file_new_for_path(filepath.c_str());
@@ -557,7 +638,7 @@ bool CtTextIterUtil::rich_text_attributes_update(const Gtk::TextIter& text_iter,
 void CtTextIterUtil::generic_process_slot(const CtConfig* const pCtConfig,
                                           const int start_offset,
                                           const int end_offset,
-                                          const Glib::RefPtr<Gtk::TextBuffer>& rTextBuffer,
+                                          const Glib::RefPtr<Gtk::TextBuffer>& pTextBuffer,
                                           SerializeFunc f_serialize_func,
                                           const bool list_info/*= false*/)
 {
@@ -566,9 +647,9 @@ void CtTextIterUtil::generic_process_slot(const CtConfig* const pCtConfig,
     for (const auto& tag_property : CtConst::TAG_PROPERTIES) {
         curr_attributes[tag_property].clear();
     }
-    Gtk::TextIter curr_start_iter = rTextBuffer->get_iter_at_offset(start_offset);
+    Gtk::TextIter curr_start_iter = pTextBuffer->get_iter_at_offset(start_offset);
     Gtk::TextIter curr_end_iter = curr_start_iter;
-    Gtk::TextIter real_end_iter = end_offset == -1 ? rTextBuffer->end() : rTextBuffer->get_iter_at_offset(end_offset);
+    Gtk::TextIter real_end_iter = end_offset == -1 ? pTextBuffer->end() : pTextBuffer->get_iter_at_offset(end_offset);
 
     if (CtTextIterUtil::rich_text_attributes_update(curr_end_iter, curr_attributes, delta_attributes)) {
         for (auto& currDelta : delta_attributes) {
@@ -592,7 +673,7 @@ void CtTextIterUtil::generic_process_slot(const CtConfig* const pCtConfig,
         }
 
         if (list_info and last_was_newline) {
-            curr_list_info = CtList{pCtConfig, rTextBuffer}.get_paragraph_list_info(curr_end_iter);
+            curr_list_info = CtList{pCtConfig, pTextBuffer}.get_paragraph_list_info(curr_end_iter);
         }
 
         last_was_newline = '\n' == curr_end_iter.get_char();
