@@ -1,7 +1,7 @@
 /*
  * ct_pref_dlg.cc
  *
- * Copyright 2009-2024
+ * Copyright 2009-2025
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -211,6 +211,14 @@ Gtk::Widget* CtPrefDlg::build_tab_interface()
     hbox_toolbar_icons_size->pack_start(*label_toolbar_icons_size, false, false);
     hbox_toolbar_icons_size->pack_start(*spinbutton_toolbar_icons_size, false, false);
 
+    auto hbox_nodes_on_node_name_header = Gtk::manage(new Gtk::Box{Gtk::ORIENTATION_HORIZONTAL, 4/*spacing*/});
+    auto label_nodes_on_node_name_header = Gtk::manage(new Gtk::Label{_("Last Visited Nodes on Node Name Header")});
+    Glib::RefPtr<Gtk::Adjustment> adj_nodes_on_node_name_header = Gtk::Adjustment::create(_pConfig->nodesOnNodeNameHeader, 0, 100, 1);
+    auto spinbutton_nodes_on_node_name_header = Gtk::manage(new Gtk::SpinButton{adj_nodes_on_node_name_header});
+    spinbutton_nodes_on_node_name_header->set_value(_pConfig->nodesOnNodeNameHeader);
+    hbox_nodes_on_node_name_header->pack_start(*label_nodes_on_node_name_header, false, false);
+    hbox_nodes_on_node_name_header->pack_start(*spinbutton_nodes_on_node_name_header, false, false);
+
     auto hbox_scrollbar_min_size = Gtk::manage(new Gtk::Box{Gtk::ORIENTATION_HORIZONTAL, 4/*spacing*/});
     auto label_scrollbar_min_size = Gtk::manage(new Gtk::Label{_("Scrollbar Slider Minimum Size (0 = System Default)")});
     Glib::RefPtr<Gtk::Adjustment> adjustment_scrollbar_min_size = Gtk::Adjustment::create(_pConfig->scrollSliderMin, 0, 1000, 1);
@@ -260,6 +268,7 @@ Gtk::Widget* CtPrefDlg::build_tab_interface()
     vbox_misc->pack_start(*checkbutton_bookmarks_top_menu, false, false);
     vbox_misc->pack_start(*checkbutton_menubar_in_titlebar, false, false);
     vbox_misc->pack_start(*hbox_toolbar_icons_size, false, false);
+    vbox_misc->pack_start(*hbox_nodes_on_node_name_header, false, false);
     vbox_misc->pack_start(*hbox_scrollbar_min_size, false, false);
     vbox_misc->pack_start(*hbox_scrollbar_overlay, false, false);
     vbox_misc->pack_start(*hbox_tooltips_enable, false, false);
@@ -373,9 +382,13 @@ Gtk::Widget* CtPrefDlg::build_tab_interface()
         _pConfig->toolbarIconSize = spinbutton_toolbar_icons_size->get_value_as_int();
         apply_for_each_window([this](CtMainWin* win) { win->set_toolbars_icon_size(_pConfig->toolbarIconSize); });
     });
+    spinbutton_nodes_on_node_name_header->signal_value_changed().connect([this, spinbutton_nodes_on_node_name_header](){
+        _pConfig->nodesOnNodeNameHeader = spinbutton_nodes_on_node_name_header->get_value_as_int();
+        apply_for_each_window([](CtMainWin* win) { win->window_header_update(); });
+    });
     spinbutton_scrollbar_min_size->signal_value_changed().connect([this, spinbutton_scrollbar_min_size](){
         _pConfig->scrollSliderMin = spinbutton_scrollbar_min_size->get_value_as_int();
-        apply_for_each_window([this](CtMainWin* win) { win->update_theme(); });
+        apply_for_each_window([](CtMainWin* win) { win->update_theme(); });
     });
     radiobutton_scrollbar_overlay_default->signal_toggled().connect([this, radiobutton_scrollbar_overlay_default](){
         if (not radiobutton_scrollbar_overlay_default->get_active()) return;
@@ -469,6 +482,8 @@ Gtk::Widget* CtPrefDlg::build_tab_links()
     Gtk::Frame* frame_links_colors = new_managed_frame_with_align(_("Colors"), grid_links_colors);
 
     auto vbox_links_misc = Gtk::manage(new Gtk::Box{Gtk::ORIENTATION_VERTICAL});
+    auto checkbutton_links_doubleclick = Gtk::manage(new Gtk::CheckButton{_("Double Click for Link Action")});
+    checkbutton_links_doubleclick->set_active(_pConfig->doubleClickLink);
     auto checkbutton_links_underline = Gtk::manage(new Gtk::CheckButton{_("Underline Links")});
     checkbutton_links_underline->set_active(_pConfig->linksUnderline);
     auto checkbutton_links_relative = Gtk::manage(new Gtk::CheckButton{_("Use Relative Paths for Files And Folders")});
@@ -480,6 +495,7 @@ Gtk::Widget* CtPrefDlg::build_tab_links()
     spinbutton_anchor_size->set_value(_pConfig->anchorSize);
     hbox_anchor_size->pack_start(*label_anchor_size, false, false);
     hbox_anchor_size->pack_start(*spinbutton_anchor_size, false, false);
+    vbox_links_misc->pack_start(*checkbutton_links_doubleclick, false, false);
     vbox_links_misc->pack_start(*checkbutton_links_underline, false, false);
     vbox_links_misc->pack_start(*checkbutton_links_relative, false, false);
     vbox_links_misc->pack_start(*hbox_anchor_size, false, false);
@@ -514,6 +530,9 @@ Gtk::Widget* CtPrefDlg::build_tab_links()
     entry_custom_folderlink_cmd->signal_changed().connect([this, entry_custom_folderlink_cmd](){
         _pConfig->folderlinkCustomAct = entry_custom_folderlink_cmd->get_text();
     });
+    checkbutton_links_doubleclick->signal_toggled().connect([this, checkbutton_links_doubleclick](){
+        _pConfig->doubleClickLink = checkbutton_links_doubleclick->get_active();
+    });
     checkbutton_links_relative->signal_toggled().connect([this, checkbutton_links_relative](){
         _pConfig->linksRelative = checkbutton_links_relative->get_active();
     });
