@@ -1,7 +1,7 @@
 /*
  * ct_pref_dlg_tree.cc
  *
- * Copyright 2009-2023
+ * Copyright 2009-2025
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -89,19 +89,11 @@ Gtk::Widget* CtPrefDlg::build_tab_tree()
     checkbutton_tree_click_focus_text->set_active(_pConfig->treeClickFocusText);
     auto checkbutton_tree_click_expand = Gtk::manage(new Gtk::CheckButton{_("Expand Node at Mouse Click")});
     checkbutton_tree_click_expand->set_active(_pConfig->treeClickExpand);
-    auto hbox_nodes_on_node_name_header = Gtk::manage(new Gtk::Box{Gtk::ORIENTATION_HORIZONTAL, 4/*spacing*/});
-    auto label_nodes_on_node_name_header = Gtk::manage(new Gtk::Label{_("Last Visited Nodes on Node Name Header")});
-    Glib::RefPtr<Gtk::Adjustment> adj_nodes_on_node_name_header = Gtk::Adjustment::create(_pConfig->nodesOnNodeNameHeader, 0, 100, 1);
-    auto spinbutton_nodes_on_node_name_header = Gtk::manage(new Gtk::SpinButton{adj_nodes_on_node_name_header});
-    spinbutton_nodes_on_node_name_header->set_value(_pConfig->nodesOnNodeNameHeader);
-    hbox_nodes_on_node_name_header->pack_start(*label_nodes_on_node_name_header, false, false);
-    hbox_nodes_on_node_name_header->pack_start(*spinbutton_nodes_on_node_name_header, false, false);
 
     vbox_misc_tree->pack_start(*hbox_tree_nodes_names_width, false, false);
     vbox_misc_tree->pack_start(*checkbutton_tree_right_side, false, false);
     vbox_misc_tree->pack_start(*checkbutton_tree_click_focus_text, false, false);
     vbox_misc_tree->pack_start(*checkbutton_tree_click_expand, false, false);
-    vbox_misc_tree->pack_start(*hbox_nodes_on_node_name_header, false, false);
     Gtk::Frame* frame_misc_tree = new_managed_frame_with_align(_("Miscellaneous"), vbox_misc_tree);
 
     auto pMainBox = Gtk::manage(new Gtk::Box{Gtk::ORIENTATION_VERTICAL, 3/*spacing*/});
@@ -132,25 +124,21 @@ Gtk::Widget* CtPrefDlg::build_tab_tree()
     checkbutton_tree_click_expand->signal_toggled().connect([this, checkbutton_tree_click_expand](){
         _pConfig->treeClickExpand = checkbutton_tree_click_expand->get_active();
     });
-    spinbutton_nodes_on_node_name_header->signal_value_changed().connect([this, spinbutton_nodes_on_node_name_header](){
-        _pConfig->nodesOnNodeNameHeader = spinbutton_nodes_on_node_name_header->get_value_as_int();
-        apply_for_each_window([](CtMainWin* win) { win->window_header_update(); });
-    });
 
     radiobutton_node_icon_cherry->signal_toggled().connect([this, radiobutton_node_icon_cherry](){
         if (!radiobutton_node_icon_cherry->get_active()) return;
         _pConfig->nodesIcons = "c";
-        apply_for_each_window([](CtMainWin* win) { win->get_tree_store().update_nodes_icon(Gtk::TreeIter(), false); });
+        apply_for_each_window([](CtMainWin* win) { win->get_tree_store().update_nodes_icon(Gtk::TreeModel::iterator(), false); });
     });
     radiobutton_node_icon_custom->signal_toggled().connect([this, radiobutton_node_icon_custom](){
         if (!radiobutton_node_icon_custom->get_active()) return;
         _pConfig->nodesIcons = "b";
-        apply_for_each_window([](CtMainWin* win) { win->get_tree_store().update_nodes_icon(Gtk::TreeIter(), false); });
+        apply_for_each_window([](CtMainWin* win) { win->get_tree_store().update_nodes_icon(Gtk::TreeModel::iterator(), false); });
     });
     radiobutton_node_icon_none->signal_toggled().connect([this, radiobutton_node_icon_none](){
         if (!radiobutton_node_icon_none->get_active()) return;
         _pConfig->nodesIcons = "n";
-        apply_for_each_window([](CtMainWin* win) { win->get_tree_store().update_nodes_icon(Gtk::TreeIter(), false); });
+        apply_for_each_window([](CtMainWin* win) { win->get_tree_store().update_nodes_icon(Gtk::TreeModel::iterator(), false); });
     });
     c_icon_button->signal_clicked().connect([this, c_icon_button](){
         auto itemStore = CtChooseDialogListStore::create();
@@ -166,12 +154,13 @@ Gtk::Widget* CtPrefDlg::build_tab_tree()
         auto res = CtDialogs::choose_item_dialog(*this,
                                                  _("Select Node Icon"),
                                                  itemStore,
-                                                 nullptr,
-                                                 std::to_string(pathSelectIdx));
+                                                 nullptr/*single_column_name*/,
+                                                 std::to_string(pathSelectIdx),
+                                                 std::make_pair(200, _pConfig->winRect[3]));
         if (res) {
             _pConfig->defaultIconText = std::stoi(res->get_value(itemStore->columns.key));
             c_icon_button->set_image(*_pCtMainWin->new_managed_image_from_stock(res->get_value(itemStore->columns.stock_id), Gtk::ICON_SIZE_BUTTON));
-            apply_for_each_window([](CtMainWin* win) { win->get_tree_store().update_nodes_icon(Gtk::TreeIter(), false);});
+            apply_for_each_window([](CtMainWin* win) { win->get_tree_store().update_nodes_icon(Gtk::TreeModel::iterator(), false);});
         }
     });
     radiobutton_nodes_startup_restore->signal_toggled().connect([this, radiobutton_nodes_startup_restore, checkbutton_nodes_bookm_exp](){
