@@ -1,7 +1,7 @@
 /*
  * ct_state_machine.cc
  *
- * Copyright 2009-2024
+ * Copyright 2009-2025
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -102,6 +102,7 @@ CtAnchoredWidgetState_EmbFile::CtAnchoredWidgetState_EmbFile(CtImageEmbFile* emb
  , rawBlob{embFile->get_raw_blob()}
  , timeSeconds{embFile->get_time()}
  , uniqueId{embFile->get_unique_id()}
+ , pathLastMultiFile{embFile->get_pathLastMultiFile()}
 {
 }
 
@@ -114,12 +115,13 @@ bool CtAnchoredWidgetState_EmbFile::equal(std::shared_ptr<CtAnchoredWidgetState>
            fileName == other_state->fileName and
            rawBlob == other_state->rawBlob and
            timeSeconds == other_state->timeSeconds and
-           uniqueId == other_state->uniqueId;
+           uniqueId == other_state->uniqueId and
+           pathLastMultiFile == other_state->pathLastMultiFile;
 }
 
 CtAnchoredWidget* CtAnchoredWidgetState_EmbFile::to_widget(CtMainWin* pCtMainWin)
 {
-    return new CtImageEmbFile{pCtMainWin, fileName, rawBlob, timeSeconds, charOffset, justification, uniqueId};
+    return new CtImageEmbFile{pCtMainWin, fileName, rawBlob, timeSeconds, charOffset, justification, uniqueId, pathLastMultiFile};
 }
 
 // Codebox
