@@ -1,7 +1,7 @@
 /*
  * ct_widgets.cc
  *
- * Copyright 2009-2024
+ * Copyright 2009-2025
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -90,15 +90,15 @@ void CtAnchoredWidget::updateJustification(const Gtk::TextIter& textIter)
     updateJustification(CtTextIterUtil::get_text_iter_alignment(textIter, _pCtMainWin));
 }
 
-void CtAnchoredWidget::insertInTextBuffer(Glib::RefPtr<Gtk::TextBuffer> rTextBuffer)
+void CtAnchoredWidget::insertInTextBuffer(Glib::RefPtr<Gtk::TextBuffer> pTextBuffer)
 {
-    _rTextChildAnchor = rTextBuffer->create_child_anchor(rTextBuffer->get_iter_at_offset(_charOffset));
+    _rTextChildAnchor = pTextBuffer->create_child_anchor(pTextBuffer->get_iter_at_offset(_charOffset));
     if (not _justification.empty()) {
-        Gtk::TextIter textIterStart = rTextBuffer->get_iter_at_child_anchor(_rTextChildAnchor);
+        Gtk::TextIter textIterStart = pTextBuffer->get_iter_at_child_anchor(_rTextChildAnchor);
         Gtk::TextIter textIterEnd = textIterStart;
         textIterEnd.forward_char();
         Glib::ustring tagName = _pCtMainWin->get_text_tag_name_exist_or_create(CtConst::TAG_JUSTIFICATION, _justification);
-        rTextBuffer->apply_tag_by_name(tagName, textIterStart, textIterEnd);
+        pTextBuffer->apply_tag_by_name(tagName, textIterStart, textIterEnd);
         std::optional<Glib::ustring> optTag = CtTextIterUtil::iter_get_tag_startingwith(textIterStart, CtConst::TAG_INVISIBLE_PREFIX);
         if (optTag.has_value()) {
             //spdlog::debug("{}", optTag.value().c_str());
@@ -128,6 +128,7 @@ CtTreeView::CtTreeView(CtConfig* pCtConfig)
  : _pCtConfig{pCtConfig}
 {
     set_headers_visible(false);
+    set_enable_search(false);
     if (_pCtConfig->treeTooltips) {
         set_tooltips_enable(true/*on*/);
     }
@@ -139,10 +140,10 @@ void CtTreeView::set_tooltips_enable(const bool on)
     else set_tooltip_column(-1);
 }
 
-void CtTreeView::set_cursor_safe(const Gtk::TreeIter& treeIter)
+void CtTreeView::set_cursor_safe(const Gtk::TreeModel::iterator& treeIter)
 {
     Gtk::TreeRow row = *treeIter;
-    Gtk::TreeIter iterParent = row.parent();
+    Gtk::TreeModel::iterator iterParent = row.parent();
     if (iterParent) {
         expand_to_path(get_model()->get_path(iterParent));
     }
