@@ -584,22 +584,22 @@ TEST(MiscUtilsGroup, parallel_for)
         }
 }
 
-TEST(MiscUtilsGroup, get_link_entry)
+TEST(MiscUtilsGroup, get_link_entry_from_property)
 {
-    ASSERT_STREQ(CtConst::LINK_TYPE_WEBS.c_str(), CtMiscUtil::get_link_entry("webs https://example.com").type.c_str());
-    ASSERT_STREQ("https://example.com", CtMiscUtil::get_link_entry("webs https://example.com").webs.c_str());
-    ASSERT_STREQ(CtConst::LINK_TYPE_FILE.c_str(), CtMiscUtil::get_link_entry("file L2hvbWUvZm9vL2Jhcgo=").type.c_str());
-    ASSERT_STREQ("/home/foo/bar\n", CtMiscUtil::get_link_entry("file L2hvbWUvZm9vL2Jhcgo=").file.c_str());
-    ASSERT_STREQ(CtConst::LINK_TYPE_FOLD.c_str(), CtMiscUtil::get_link_entry("fold L2hvbWUvZm9vL2Jhcgo=").type.c_str());
-    ASSERT_STREQ("/home/foo/bar\n", CtMiscUtil::get_link_entry("fold L2hvbWUvZm9vL2Jhcgo=").fold.c_str());
-    ASSERT_STREQ(CtConst::LINK_TYPE_NODE.c_str(), CtMiscUtil::get_link_entry("node 2 hi hi").type.c_str());
-    ASSERT_TRUE(CtMiscUtil::get_link_entry("node 2 hi hi").node_id == 2);
-    ASSERT_STREQ("hi hi", CtMiscUtil::get_link_entry("node 2 hi hi").anch.c_str());
+    ASSERT_EQ(CtLinkType::Webs, CtMiscUtil::get_link_entry_from_property("webs https://example.com").type);
+    ASSERT_STREQ("https://example.com", CtMiscUtil::get_link_entry_from_property("webs https://example.com").webs.c_str());
+    ASSERT_EQ(CtLinkType::File, CtMiscUtil::get_link_entry_from_property("file L2hvbWUvZm9vL2Jhcgo=").type);
+    ASSERT_STREQ("/home/foo/bar\n", CtMiscUtil::get_link_entry_from_property("file L2hvbWUvZm9vL2Jhcgo=").file.c_str());
+    ASSERT_EQ(CtLinkType::Fold, CtMiscUtil::get_link_entry_from_property("fold L2hvbWUvZm9vL2Jhcgo=").type);
+    ASSERT_STREQ("/home/foo/bar\n", CtMiscUtil::get_link_entry_from_property("fold L2hvbWUvZm9vL2Jhcgo=").fold.c_str());
+    ASSERT_EQ(CtLinkType::Node, CtMiscUtil::get_link_entry_from_property("node 2 hi hi").type);
+    ASSERT_TRUE(CtMiscUtil::get_link_entry_from_property("node 2 hi hi").node_id == 2);
+    ASSERT_STREQ("hi hi", CtMiscUtil::get_link_entry_from_property("node 2 hi hi").anch.c_str());
 
-    ASSERT_STREQ("", CtMiscUtil::get_link_entry("").type.c_str());
-    ASSERT_STREQ("", CtMiscUtil::get_link_entry("https://example.com").type.c_str());
-    ASSERT_STREQ("", CtMiscUtil::get_link_entry("/home/foo/bar").type.c_str());
-    ASSERT_STREQ("", CtMiscUtil::get_link_entry("home https://example.com").type.c_str());
+    ASSERT_EQ(CtLinkType::None, CtMiscUtil::get_link_entry_from_property("").type);
+    ASSERT_EQ(CtLinkType::None, CtMiscUtil::get_link_entry_from_property("https://example.com").type);
+    ASSERT_EQ(CtLinkType::None, CtMiscUtil::get_link_entry_from_property("/home/foo/bar").type);
+    ASSERT_EQ(CtLinkType::None, CtMiscUtil::get_link_entry_from_property("home https://example.com").type);
 }
 
 TEST(MiscUtilsGroup, get_is_camel_case)
@@ -640,3 +640,18 @@ TEST(MiscUtilsGroup, gtk_pango_find_start_of_dir)
     ASSERT_EQ(8, CtStrUtil::gtk_pango_find_start_of_dir("Test 123" "עִבְרִית", PANGO_DIRECTION_RTL));
     ASSERT_EQ(16, CtStrUtil::gtk_pango_find_start_of_dir("עִבְרִית" "Test 123", PANGO_DIRECTION_LTR));
 }
+
+TEST(MiscUtilsGroup, contains_words)
+{
+    ASSERT_TRUE(CtStrUtil::contains_words(Glib::ustring{"uno due tre"}, {Glib::ustring{"due"}, Glib::ustring{"tre"}}));
+    ASSERT_FALSE(CtStrUtil::contains_words(Glib::ustring{"uno due tre"}, {Glib::ustring{"tre"}, Glib::ustring{"quattro"}}));
+    ASSERT_TRUE(CtStrUtil::contains_words(Glib::ustring{"uno due tre"}, {Glib::ustring{"tre"}, Glib::ustring{"quattro"}}, false/*require_all*/));
+    ASSERT_FALSE(CtStrUtil::contains_words(Glib::ustring{"uno due tre"}, {Glib::ustring{"quattro"}, Glib::ustring{"cinque"}}, false/*require_all*/));
+}
+
+TEST(MiscUtilsGroup, highlight_words)
+{
+    ASSERT_STREQ("uno <b>due</b> <b>tre</b>", CtStrUtil::highlight_words(Glib::ustring{"uno due tre"}, {Glib::ustring{"due"}, Glib::ustring{"tre"}}).c_str());
+    ASSERT_STREQ("uno <u>due</u> <u>tre</u>", CtStrUtil::highlight_words(Glib::ustring{"uno due tre"}, {Glib::ustring{"due"}, Glib::ustring{"tre"}}, "u").c_str());
+    ASSERT_STREQ("uno <b>due</b> <b>tre</b>", CtStrUtil::highlight_words(Glib::ustring{"uno due tre"}, {Glib::ustring{"tre"}, Glib::ustring{"due"}}).c_str());
+}
